@@ -20,7 +20,7 @@
 
 using namespace ARTICLE;
 
-Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std::string command )
+Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std::string& command )
     : SKELETON::PrefDiag( parent, url )
     ,m_label_name( false, "スレタイトル : ", DBTREE::article_subject( get_url() ) )
     ,m_label_url( false, "スレのURL : ", DBTREE:: url_readcgi( get_url(),0,0 ) )
@@ -143,7 +143,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
         int save = 0;
         for( const int res : tmp_set ) {
             if( !pre_res ) {
-                pre_res = save = res;
+                save = res;
             }
             else if( res - pre_res > 1 ) {
                 str_res.append( std::to_string( save ) );
