@@ -172,6 +172,10 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     m_treeview.set_show_expanders( CONFIG::get_tree_show_expanders() );
     m_treeview.set_level_indentation( CONFIG::get_tree_level_indent() );
 
+#if GTKMM_CHECK_VERSION(3,3,18)
+    m_treeview.add_events( Gdk::SMOOTH_SCROLL_MASK );
+#endif
+
     // treeviewのシグナルにコネクト
     m_treeview.signal_row_expanded().connect( sigc::mem_fun(*this, &BBSListViewBase::slot_row_exp ) );
     m_treeview.signal_row_collapsed().connect( sigc::mem_fun(*this, &BBSListViewBase::slot_row_col ) );
@@ -1035,7 +1039,7 @@ void BBSListViewBase::next_dir()
 //
 // 他のviewのtreestoreをcopyして表示
 //
-void BBSListViewBase::copy_treestore( Glib::RefPtr< Gtk::TreeStore >& store )
+void BBSListViewBase::copy_treestore( const Glib::RefPtr< Gtk::TreeStore >& store )
 {
 #ifdef _DEBUG
     std::cout << "BBSListViewBase::copy_treestore\n";
@@ -1149,21 +1153,20 @@ bool BBSListViewBase::slot_motion_notify( GdkEventMotion* event )
     if( m_treeview.get_path_at_pos( x, y, path, column, cell_x, cell_y ) && m_treeview.get_row( path ) ){
 
         Gtk::TreeModel::Row row = m_treeview.get_row( path );
-        Glib::ustring subject = row[ m_columns.m_name ];
-        Glib::ustring url = row[ m_columns.m_url ];
+        const Glib::ustring& ustr_url = row[ m_columns.m_url ];
         int type = row[ m_columns.m_type ];
 
-        m_treeview.reset_pre_popupurl( url );
+        m_treeview.reset_pre_popupurl( ustr_url.raw() );
 
         // 画像ポップアップ
         if( type == TYPE_IMAGE ){
 
-            if( DBIMG::get_type_ext( url ) != DBIMG::T_UNKNOWN && DBIMG::get_code( url ) != HTTP_INIT ){
+            if( DBIMG::get_type_ext( ustr_url.raw() ) != DBIMG::T_UNKNOWN && DBIMG::get_code( ustr_url.raw() ) != HTTP_INIT ){
 
-                if( m_treeview.pre_popup_url() != url ){
+                if( m_treeview.pre_popup_url() != ustr_url.raw() ){
 
-                    SKELETON::View* view = CORE::ViewFactory( CORE::VIEW_IMAGEPOPUP,  url );
-                    m_treeview.show_popup( url, view );
+                    SKELETON::View* view = CORE::ViewFactory( CORE::VIEW_IMAGEPOPUP, ustr_url.raw() );
+                    m_treeview.show_popup( ustr_url.raw(), view );
                 }
             }
             else m_treeview.hide_popup();
@@ -1540,6 +1543,7 @@ void BBSListViewBase::add_newetcboard( const bool move, // true なら編集モ
             if( row ){
                 row[ m_columns.m_url ] = url;
                 row[ m_columns.m_name ] = name;
+                static_cast<void>( row ); // cppcheck: unreadVariable
             }
         }
 
@@ -2274,7 +2278,7 @@ void BBSListViewBase::xml2tree( const std::string& root_name, const std::string&
     m_treeview.xml2tree( m_document, m_treestore, root_name );
 
     // ルート要素を取り出す
-    XML::Dom* root = m_document.get_root_element( root_name );
+    const XML::Dom* root = m_document.get_root_element( root_name );
     if( root ){
 
 	// ルート要素から属性( date_modified, path, y )の値を取得
@@ -2333,7 +2337,7 @@ void BBSListViewBase::update_urls()
     for( ; ! it.end(); ++it ){
 
         Gtk::TreeModel::Row row = *it;
-        const Glib::ustring url = row[ m_columns.m_url ];
+        const Glib::ustring& ustr_url = row[ m_columns.m_url ];
         const int type = row[ m_columns.m_type ];
 
 #ifdef _DEBUG
@@ -2346,12 +2350,12 @@ void BBSListViewBase::update_urls()
             case TYPE_BOARD: // 板
             case TYPE_BOARD_UPDATE:
 
-                url_new = DBTREE::url_boardbase( url );
-                if( url != url_new ){
+                url_new = DBTREE::url_boardbase( ustr_url.raw() );
+                if( ustr_url.raw() != url_new ){
                     updated = true;
                     row[ m_columns.m_url ] = url_new;
 #ifdef _DEBUG
-                    std::cout << url << " -> " << url_new << std::endl;
+                    std::cout << ustr_url << " -> " << url_new << std::endl;
 #endif
                 }
 
@@ -2359,19 +2363,19 @@ void BBSListViewBase::update_urls()
                 break;
 
             case TYPE_VBOARD:
-                m_set_board.insert( url );
+                m_set_board.insert( ustr_url.raw() );
                 break;
 
             case TYPE_THREAD: // スレ
             case TYPE_THREAD_UPDATE:
             case TYPE_THREAD_OLD:
 
-                url_new = DBTREE::url_dat( url );
-                if( url != url_new ){
+                url_new = DBTREE::url_dat( ustr_url.raw() );
+                if( ustr_url.raw() != url_new ){
                     updated = true;
                     row[ m_columns.m_url ] = url_new;
 #ifdef _DEBUG
-                    std::cout << url << " -> " << url_new << std::endl;
+                    std::cout << ustr_url << " -> " << url_new << std::endl;
 #endif
                 }
 
@@ -2379,7 +2383,7 @@ void BBSListViewBase::update_urls()
                 break;
 
             case TYPE_IMAGE:
-                m_set_image.insert( url );
+                m_set_image.insert( ustr_url.raw() );
                 break;
         }
     }
@@ -2419,12 +2423,12 @@ void BBSListViewBase::toggle_articleicon( const std::string& url )
     for( ; ! it.end(); ++it ){
 
         Gtk::TreeModel::Row row = *it;
-        const Glib::ustring url_row = row[ m_columns.m_url ];
+        const Glib::ustring& url_row = row[ m_columns.m_url ];
         const int type_row = row[ m_columns.m_type ];
 
         if( type_row == TYPE_THREAD || type_row == TYPE_THREAD_UPDATE || type_row == TYPE_THREAD_OLD ){
 
-            if( url == url_row ){
+            if( url == url_row.raw() ){
 #ifdef _DEBUG
                 std::cout << "hit " << url << " == " << url_row << std::endl;
                 std::cout << row2name( row ) << std::endl;
@@ -2468,12 +2472,12 @@ void BBSListViewBase::toggle_boardicon( const std::string& url )
     for( ; ! it.end(); ++it ){
 
         Gtk::TreeModel::Row row = *it;
-        const Glib::ustring url_row = row[ m_columns.m_url ];
+        const Glib::ustring& url_row = row[ m_columns.m_url ];
         const int type_row = row[ m_columns.m_type ];
 
         if( type_row == TYPE_BOARD || type_row == TYPE_BOARD_UPDATE ){
 
-            if( url_boardbase == url_row ){
+            if( url_boardbase == url_row.raw() ){
 #ifdef _DEBUG
                 std::cout << "hit " << url_boardbase << " == " << url_row << std::endl;
                 std::cout << row2name( row ) << std::endl;
@@ -2519,10 +2523,10 @@ void BBSListViewBase::select_item( const std::string& url )
     }
 
     // 現在選択しているものと一致する場合は何もしない
-    Gtk::TreePath path = m_treeview.get_current_path();
-    if( ! path.empty() ){
+    Gtk::TreePath current_path = m_treeview.get_current_path();
+    if( ! current_path.empty() ){
         // 板一覧やお気に入りに、該当するURLが2つある場合がある
-        if( url_item == path2rawurl( path ) || url_item == path2url( path ) ) return;
+        if( url_item == path2rawurl( current_path ) || url_item == path2url( current_path ) ) return;
     }
 
     Gtk::TreePath closed_path;
@@ -2606,7 +2610,7 @@ void BBSListViewBase::replace_thread( const std::string& url, const std::string&
     for( ; ! it.end(); ++it ){
 
         Gtk::TreeModel::Row row = *it;
-        const Glib::ustring url_row = row[ m_columns.m_url ];
+        const Glib::ustring& ustr_url = row[ m_columns.m_url ];
 
         switch( row[ m_columns.m_type ] ){
 
@@ -2614,7 +2618,7 @@ void BBSListViewBase::replace_thread( const std::string& url, const std::string&
             case TYPE_THREAD_UPDATE:
             case TYPE_THREAD_OLD:
 
-                if( urldat == url_row || urlcgi == url_row ){
+                if( urldat == ustr_url.raw() ){
 
                     if( show_diag ){
 
@@ -2659,11 +2663,11 @@ void BBSListViewBase::replace_thread( const std::string& url, const std::string&
 
                         // 名前が古いものであったら更新
                         // 手動で変更されていたらそのまま
-                        const Glib::ustring name_row = row[ m_columns.m_name ];
+                        const Glib::ustring& ustr_name = row[ m_columns.m_name ];
 #ifdef _DEBUG
-                        std::cout << "name_row = " << name_row << std::endl;
+                        std::cout << "name_row = " << ustr_name << std::endl;
 #endif
-                        if( MISC::remove_space( name_row ) == name_old ){
+                        if( ustr_name.raw() == name_old ){
 #ifdef _DEBUG
                             std::cout << "replace name\n";
 #endif
@@ -2997,8 +3001,6 @@ void BBSListViewBase::get_threads( const size_t dirid, std::vector< std::string
     std::cout << "BBSListViewBase::get_threads " << dirid << std::endl;
 #endif
 
-    std::list< Gtk::TreePath > list_path;
-
     Gtk::TreePath path = m_treeview.dirid_to_path( dirid );
     if( dirid && path.empty() ) return;
 
@@ -3048,7 +3050,7 @@ void BBSListViewBase::remove_item( const std::string& url )
     for( ; ! it.end(); ++it ){
 
         Gtk::TreeModel::Row row = *it;
-        const Glib::ustring url = row[ m_columns.m_url ];
+        const Glib::ustring& url_row = row[ m_columns.m_url ];
         const int type = row[ m_columns.m_type ];
 
         switch( type ){
@@ -3062,9 +3064,9 @@ void BBSListViewBase::remove_item( const std::string& url )
 
             case TYPE_IMAGE: // 画像
 
-                if( url == url_target ){
+                if( url_row.raw() == url_target ){
 #ifdef _DEBUG
-                    std::cout << "hit " << url << " == " << url_target << std::endl;
+                    std::cout << "hit " << url_row << " == " << url_target << std::endl;
                     std::cout << row2name( row ) << std::endl;
 #endif
                     list_path.push_back( it.get_path() );
@@ -3224,17 +3226,14 @@ void BBSListViewBase::save_xml_impl( const std::string& file, const std::string&
     if( ! remove_dir.empty() )
     {
         XML::Dom* domroot = m_document.get_root_element( root );
-        XML::DomList domlist = domroot->childNodes();
-        std::list< XML::Dom* >::iterator it = domlist.begin();
-        while( it != domlist.end() )
+        for( XML::Dom* child : domroot->childNodes() )
         {
-            if( (*it)->nodeName() == "subdir"
-                && (*it)->getAttribute( "name" ) == remove_dir )
+            if( child->nodeName() == "subdir"
+                && child->getAttribute( "name" ) == remove_dir )
             {
-                domroot->removeChild( *it );
+                domroot->removeChild( child );
                 break;
             }
-            ++it;
         }
     }
 
