@@ -182,7 +182,7 @@ namespace BBSLIST
 
       public:
 
-        BBSListViewBase( const std::string& url, const std::string& arg1 = std::string() , const std::string& arg2 = std::string() );
+        explicit BBSListViewBase( const std::string& url, const std::string& arg1 = {}, const std::string& arg2 = {} );
         ~BBSListViewBase();
 
         //
@@ -246,7 +246,7 @@ namespace BBSLIST
 
         // selectdialogで使う
         Gtk::TreePath get_current_path() { return m_treeview.get_current_path(); }
-        void copy_treestore( Glib::RefPtr< Gtk::TreeStore >& store );
+        void copy_treestore( const Glib::RefPtr< Gtk::TreeStore >& store );
 
         // undo, redo
         void undo();
