@@ -162,6 +162,10 @@ BoardViewBase::BoardViewBase( const std::string& url, const bool show_col_board
     m_liststore->set_sort_func( COL_SPEED, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
     m_liststore->set_sort_func( COL_DIFF, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
 
+#if GTKMM_CHECK_VERSION(3,3,18)
+    m_treeview.add_events( Gdk::SMOOTH_SCROLL_MASK );
+#endif
+
     m_treeview.sig_button_press().connect( sigc::mem_fun(*this, &BoardViewBase::slot_button_press ) );
     m_treeview.sig_button_release().connect( sigc::mem_fun(*this, &BoardViewBase::slot_button_release ) );
     m_treeview.sig_motion_notify().connect( sigc::mem_fun(*this, &BoardViewBase::slot_motion_notify ) );
@@ -574,6 +578,9 @@ void BoardViewBase::update_columns()
         ++num;
     }
 
+    // 高さを取得するためのcolumn番号をリセット
+    m_treeview.set_column_for_height( 0 );
+
     // サイズを調整しつつソートの設定
     for( guint i = 0; i < COL_VISIBLE_END; i++ ){
 
@@ -601,7 +608,7 @@ void BoardViewBase::update_columns()
 
         case COL_SUBJECT:
             width = SESSION::col_subject();
-            m_treeview.set_column_for_height( id );
+            m_treeview.set_column_for_height( i );
             break;
 
         case COL_RES:
@@ -831,11 +838,6 @@ void BoardViewBase::save_column_width()
 void BoardViewBase::slot_cell_data( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& it )
 {
     Gtk::TreeModel::Row row = *it;
-    Gtk::TreePath path = GET_PATH( row );
-
-#ifdef _DEBUG
-//    std::cout << "BoardViewBase::slot_cell_data path = " << path.to_string() << std::endl;
-#endif
 
     // ハイライト色 ( 抽出状態 )
     if( row[ m_columns.m_col_drawbg ] ){
@@ -966,7 +968,7 @@ void BoardViewBase::slot_col_clicked( const int col )
 //
 // row_a が上か　row_b　が上かを返す。同じ状態なら 0
 //
-int BoardViewBase::compare_drawbg( Gtk::TreeModel::Row& row_a, Gtk::TreeModel::Row& row_b )
+int BoardViewBase::compare_drawbg( const Gtk::TreeModel::Row& row_a, const Gtk::TreeModel::Row& row_b ) const
 {
     const bool draw_a = row_a[ m_columns.m_col_drawbg ];
     const bool draw_b = row_b[ m_columns.m_col_drawbg ];
@@ -983,7 +985,8 @@ int BoardViewBase::compare_drawbg( Gtk::TreeModel::Row& row_a, Gtk::TreeModel::R
 //
 // row_a が上か　row_b　が上かを返す。同じなら 0
 //
-int BoardViewBase::compare_col( const int col, const int sortmode, Gtk::TreeModel::Row& row_a, Gtk::TreeModel::Row& row_b )
+int BoardViewBase::compare_col( const int col, const int sortmode,
+                                const Gtk::TreeModel::Row& row_a, const Gtk::TreeModel::Row& row_b ) const
 {
     int num_a = 0, num_b = 0;
     int ret = 0;
@@ -1849,14 +1852,10 @@ void BoardViewBase::update_row_common( const Gtk::TreeModel::Row& row )
     // 読み込み数
 
     if( load ){
-        const int tmpsize = 32;
-        char tmp[ tmpsize ];
-        snprintf( tmp, tmpsize, "%d", load );
-        row[ m_columns.m_col_str_load ] = tmp;
-        snprintf( tmp, tmpsize, "%d", res - load );
-        row[ m_columns.m_col_str_new ] = tmp;
-
-        row[ m_columns.m_col_new ] = res - load;
+        row[ m_columns.m_col_str_load ] = Glib::ustring::compose( "%1", load );
+        const int new_arrival = res - load;
+        row[ m_columns.m_col_str_new ] = Glib::ustring::compose( "%1", new_arrival );;
+        row[ m_columns.m_col_new ] = new_arrival;
     }
     else{
         row[ m_columns.m_col_str_load ] = "";
@@ -2431,7 +2430,7 @@ void BoardViewBase::slot_open_browser()
 //
 // 記事を開く
 //
-bool BoardViewBase::open_row( Gtk::TreePath& path, const bool tab, const bool reget )
+bool BoardViewBase::open_row( const Gtk::TreePath& path, const bool tab, const bool reget )
 {
     std::string str_tab = "false";
     if( tab ) str_tab = "opentab";
