@@ -22,7 +22,7 @@
 
 using namespace BOARD;
 
-Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std::string command )
+Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std::string& command )
     : SKELETON::PrefDiag( parent, url ),
       m_frame_write( "書き込み設定" ),
       m_entry_writename( true, "名前：" ),
@@ -104,17 +104,19 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
 
     // cookie と 書き込みキーワード の設定
     std::string str_cookies;
-    std::list< std::string > list_cookies = DBTREE::board_list_cookies_for_write( get_url() );
-    if( list_cookies.empty() ) str_cookies = "クッキー:\n未取得\n";
-    else{
-        str_cookies = "クッキー:\n";
-        std::list< std::string >::iterator it = list_cookies.begin();
-        for( ; it != list_cookies.end(); ++it )
-            str_cookies += MISC::Iconv( (*it), DBTREE::board_charset( get_url() ), "UTF-8" ) + "\n";
+    const std::string temp_cookies = DBTREE::board_cookie_by_host( get_url() );
+    if( temp_cookies.empty() ) {
+        str_cookies = "クッキー:\n未取得\n";
+    }
+    else {
+        str_cookies = "クッキー:\n" + MISC::Iconv( temp_cookies, DBTREE::board_charset( get_url() ), "UTF-8" ) + "\n";
     }
 
-    const std::string keyword = DBTREE::board_keyword_for_write( get_url() );
-    if( ! keyword.empty() ) str_cookies += "\nキーワード: " + keyword + "\n";
+    std::string keyword = DBTREE::board_keyword_for_write( get_url() );
+    if( ! keyword.empty() ) str_cookies.append( "\n書き込み用キーワード: " + keyword + "\n" );
+
+    keyword = DBTREE::board_keyword_for_newarticle( get_url() );
+    if( ! keyword.empty() ) str_cookies.append( "\nスレ立て用キーワード: " + keyword + "\n" );
 
     m_edit_cookies.set_text( str_cookies );
 
@@ -417,8 +419,9 @@ void Preferences::slot_set_default_namemail()
 
 void Preferences::slot_delete_cookie()
 {
-    DBTREE::board_reset_list_cookies_for_write( get_url() );
+    DBTREE::board_delete_cookies( get_url() );
     DBTREE::board_set_keyword_for_write( get_url(), std::string() );
+    DBTREE::board_set_keyword_for_newarticle( get_url(), std::string() );
 
     m_edit_cookies.set_text( "クッキー:\n未取得\n" );
 }
