@@ -60,11 +60,9 @@ std::string get_default_font()
 
 
 ConfigItems::ConfigItems()
-    : m_loaded( false )
-{
-    str_color.resize( COLOR_NUM );
-    fontname.resize( FONT_NUM );
-}
+    : fontname( FONT_NUM )
+    , str_color( COLOR_NUM )
+{}
 
 ConfigItems::~ConfigItems() noexcept = default;
 
@@ -111,18 +109,23 @@ bool ConfigItems::load( const bool restore )
 
     // 読み込み用プロクシとポート番号
     use_proxy_for2ch = cf.get_option_bool( "use_proxy_for2ch", CONF_USE_PROXY_FOR2CH );
+    send_cookie_to_proxy_for2ch = cf.get_option_bool( "send_cookie_to_proxy_for2ch", CONF_SEND_COOKIE_TO_PROXY_FOR2CH );
     str_tmp = cf.get_option_str( "proxy_for2ch", "" );
     set_proxy_for2ch( str_tmp );
     proxy_port_for2ch = cf.get_option_int( "proxy_port_for2ch", CONF_PROXY_PORT_FOR2CH, 1, 65535 );
 
     // 書き込み用プロクシとポート番号
     use_proxy_for2ch_w = cf.get_option_bool( "use_proxy_for2ch_w", CONF_USE_PROXY_FOR2CH_W );
+    send_cookie_to_proxy_for2ch_w = cf.get_option_bool( "send_cookie_to_proxy_for2ch_w",
+                                                        CONF_SEND_COOKIE_TO_PROXY_FOR2CH_W );
     str_tmp = cf.get_option_str( "proxy_for2ch_w", "" );
     set_proxy_for2ch_w( str_tmp );
     proxy_port_for2ch_w = cf.get_option_int( "proxy_port_for2ch_w", CONF_PROXY_PORT_FOR2CH_W, 1, 65535 );
 
     // 2chの外にアクセスするときのプロクシとポート番号
     use_proxy_for_data = cf.get_option_bool( "use_proxy_for_data", CONF_USE_PROXY_FOR_DATA );
+    send_cookie_to_proxy_for_data = cf.get_option_bool( "send_cookie_to_proxy_for_data",
+                                                        CONF_SEND_COOKIE_TO_PROXY_FOR_DATA );
     str_tmp = cf.get_option_str( "proxy_for_data", "" );
     set_proxy_for_data( str_tmp );
     proxy_port_for_data = cf.get_option_int( "proxy_port_for_data", CONF_PROXY_PORT_FOR_DATA, 1, 65535 );
@@ -152,16 +155,13 @@ bool ConfigItems::load( const bool restore )
     // 同一ホストに対する最大コネクション数( 1 または 2 )
     connection_num = cf.get_option_int( "connection_num", CONF_CONNECTION_NUM, 1, 2 );
 
-    // 2chのクッキー:HAPを保存する
+    // 2chのクッキーを保存する (互換性のため設定名は旧名称を使う)
     use_cookie_hap = cf.get_option_bool( "use_cookie_hap", CONF_USE_COOKIE_HAP );
 
-    // 2chのクッキー:HAP
+    // 2chのクッキー (互換性のため設定名は旧名称を使う)
     cookie_hap = cf.get_option_str( "cookie_hap", CONF_COOKIE_HAP );
     cookie_hap_bbspink = cf.get_option_str( "cookie_hap_bbspink", CONF_COOKIE_HAP_BBSPINK );
 
-    // 2chの過去ログ取得時にofflaw2を使用する
-    use_offlaw2_2ch = cf.get_option_bool( "use_offlaw2_2ch", CONF_USE_OFFLAW2_2CH );
-
     // ブラウザ設定ダイアログのコンボボックスの番号
     browsercombo_id = cf.get_option_int( "browsercombo_id", CONF_BROWSER_NO, 0, CORE::get_browser_number() -1 );
 
@@ -241,9 +241,6 @@ bool ConfigItems::load( const bool restore )
     // 2chの認証サーバのアドレス
     url_login2ch = cf.get_option_str( "url_login2ch", CONF_LOGIN2CH );
 
-    // p2の認証サーバのアドレス
-    url_loginp2 = cf.get_option_str( "url_loginp2", CONF_LOGINP2 );
-
     // BEの認証サーバのアドレス
     url_loginbe = cf.get_option_str( "url_loginbe", CONF_LOGINBE );
 
@@ -260,10 +257,6 @@ bool ConfigItems::load( const bool restore )
     menu_search_title = cf.get_option_str( "menu_search_title", CONF_MENU_SEARCH_TITLE );
     url_search_title = cf.get_option_str( "url_search_title", CONF_URL_SEARCH_TITLE );
 
-    // p2 書き込み用アドレス
-    url_writep2 = cf.get_option_str( "url_writep2", CONF_URL_WRITEP2 );
-    url_resp2 = cf.get_option_str( "url_resp2", CONF_URL_RESP2 );
-
     // スレタイ検索用正規表現
     regex_search_title = cf.get_option_str( "regex_search_title", CONF_REGEX_SEARCH_TITLE );
 
@@ -289,7 +282,7 @@ bool ConfigItems::load( const bool restore )
     // ツリービューのレベルインデント調整量(ピクセル)
     tree_level_indent = cf.get_option_int( "tree_level_indent", CONF_TREE_LEVEL_INDENT, -256, 256 );
 
-    // カテゴリを開いたときにツリービューをスクロールする
+    // カテゴリやディレクトリを開いたときにツリービューをスクロールする
     scroll_tree = cf.get_option_bool( "scroll_tree", CONF_SCROLL_TREE );
 
     // ツリービューの選択を表示中のビューと同期する
@@ -349,7 +342,7 @@ bool ConfigItems::load( const bool restore )
     // 板一覧でカテゴリを常にひとつだけ開く
     open_one_category = cf.get_option_bool( "open_one_category", CONF_OPEN_ONE_CATEGORY );
 
-    // お気に入りでカテゴリを常にひとつだけ開く
+    // お気に入りでディレクトリを常にひとつだけ開く
     open_one_favorite = cf.get_option_bool( "open_one_favorite", CONF_OPEN_ONE_FAVORITE );
 
     // デフォルトの書き込み名
@@ -489,9 +482,6 @@ bool ConfigItems::load( const bool restore )
     // ツールバーの背景描画
     draw_toolbarback = cf.get_option_bool( "draw_toolbarback", CONF_DRAW_TOOLBARBACK );
 
-    std::list< std::string > list_tmp;
-    std::list< std::string >::iterator it_tmp;
-
     // スレ あぼーん word
     str_tmp = cf.get_option_str( "abonewordthread", "" );
     if( ! str_tmp.empty() ) list_abone_word_thread = MISC::strtolist( str_tmp );
@@ -653,7 +643,6 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "url_jdhp", url_jdhp );
     cf.update( "url_jdimhp", url_jdimhp );
     cf.update( "url_login2ch", url_login2ch );
-    cf.update( "url_loginp2", url_loginp2 );
     cf.update( "url_loginbe", url_loginbe );
     cf.update( "url_bbsmenu", url_bbsmenu );
     cf.update( "use_link_as_board", use_link_as_board );
@@ -663,10 +652,9 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "regex_search_title", regex_search_title );
     cf.update( "menu_search_web", menu_search_web );
     cf.update( "url_search_web", url_search_web );
-    cf.update( "url_writep2", url_writep2 );
-    cf.update( "url_resp2", url_resp2 );
 
     cf.update( "fontname_main", fontname[ FONT_MAIN ] );
+    cf.update( "fontname_mail", fontname[ FONT_MAIL ] );
     cf.update( "fontname_popup", fontname[ FONT_POPUP ] );
     cf.update( "fontname_aa", fontname[ FONT_AA ] );
     cf.update( "fontname_bbs", fontname[ FONT_BBS ] );
@@ -684,12 +672,14 @@ void ConfigItems::save_impl( const std::string& path )
     if( proxy_basicauth_for2ch.empty() ) tmp_proxy = proxy_for2ch;
     else tmp_proxy = proxy_basicauth_for2ch + "@" + proxy_for2ch;
     cf.update( "use_proxy_for2ch", use_proxy_for2ch );
+    cf.update( "send_cookie_to_proxy_for2ch", send_cookie_to_proxy_for2ch );
     cf.update( "proxy_for2ch", tmp_proxy );
     cf.update( "proxy_port_for2ch", proxy_port_for2ch );
 
     if( proxy_basicauth_for2ch_w.empty() ) tmp_proxy = proxy_for2ch_w;
     else tmp_proxy = proxy_basicauth_for2ch_w + "@" + proxy_for2ch_w;
     cf.update( "use_proxy_for2ch_w", use_proxy_for2ch_w );
+    cf.update( "send_cookie_to_proxy_for2ch_w", send_cookie_to_proxy_for2ch_w );
     cf.update( "proxy_for2ch_w", tmp_proxy );
     cf.update( "proxy_port_for2ch_w", proxy_port_for2ch_w );
 
@@ -698,6 +688,7 @@ void ConfigItems::save_impl( const std::string& path )
     if( proxy_basicauth_for_data.empty() ) tmp_proxy = proxy_for_data;
     else tmp_proxy = proxy_basicauth_for_data + "@" + proxy_for_data;
     cf.update( "use_proxy_for_data", use_proxy_for_data );
+    cf.update( "send_cookie_to_proxy_for_data", send_cookie_to_proxy_for_data );
     cf.update( "proxy_for_data", tmp_proxy );
     cf.update( "proxy_port_for_data", proxy_port_for_data );
 
@@ -718,8 +709,6 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "cookie_hap", cookie_hap );
     cf.update( "cookie_hap_bbspink", cookie_hap_bbspink );
 
-    cf.update( "use_offlaw2_2ch", use_offlaw2_2ch );
-
     cf.update( "command_openurl", command_openurl );
     cf.update( "browsercombo_id", browsercombo_id );
 
@@ -950,6 +939,7 @@ void ConfigItems::set_fonts( JDLIB::ConfLoader& cf )
 
     // フォント
     fontname[ FONT_MAIN ] = cf.get_option_str( "fontname_main", defaultfont + " " + std::string( CONF_FONTSIZE_THREAD ) );
+    fontname[ FONT_MAIL ] = cf.get_option_str( "fontname_mail", defaultfont + " " + std::string( CONF_FONTSIZE_MAIL ) );
 
     // ポップアップのフォント
     fontname[ FONT_POPUP ] = cf.get_option_str( "fontname_popup", defaultfont + " " + std::string( CONF_FONTSIZE_POPUP ) );
