@@ -23,10 +23,13 @@ namespace CONFIG
 #endif
         CONF_REF_PREFIX_SPACE = 1, // 参照文字( CONF_REF_PREFIX ) の後のスペースの数
         CONF_USE_PROXY_FOR2CH = 0, // 2ch 読み込み用プロクシを使用するか
+        CONF_SEND_COOKIE_TO_PROXY_FOR2CH = 0, // 2ch 読み込み用プロクシにクッキーを送信するか
         CONF_PROXY_PORT_FOR2CH = 8080, // 2ch 読み込み用プロクシポート番号
         CONF_USE_PROXY_FOR2CH_W = 0, // 2ch 書き込み用プロクシを使用するか
+        CONF_SEND_COOKIE_TO_PROXY_FOR2CH_W = 0, // 2ch 書き込み用プロクシにクッキーを送信するか
         CONF_PROXY_PORT_FOR2CH_W = 8080, // 2ch 書き込み用プロクシポート番号
         CONF_USE_PROXY_FOR_DATA = 0, // 2ch 以外にアクセスするときにプロクシを使用するか
+        CONF_SEND_COOKIE_TO_PROXY_FOR_DATA = 0, // 2ch 以外にアクセスするときのプロクシにクッキーを送信するか
         CONF_PROXY_PORT_FOR_DATA = 8080, // 2ch 以外にアクセスするときのプロクシポート番号
         CONF_LOADER_BUFSIZE = 32,   // ローダのバッファサイズ (一般)
         CONF_LOADER_BUFSIZE_BOARD = 2,   // ローダのバッファサイズ (スレ一覧用)
@@ -36,8 +39,7 @@ namespace CONFIG
         CONF_LOADER_TIMEOUT_CHECKUPDATE = 10,  // 更新チェックのタイムアウト値
         CONF_USE_IPV6 = 1,          // ipv6使用
         CONF_CONNECTION_NUM = 2,    // 同一ホストに対する最大コネクション数( 1 または 2 )
-        CONF_USE_COOKIE_HAP = 0,    // 2chのクッキー:HAPを保存する
-        CONF_USE_OFFLAW2_2CH = 0,   // 2chの過去ログ取得時にofflaw2を使用する
+        CONF_USE_COOKIE_HAP = 0,    // 2chのクッキーを保存する (互換性のため設定名は旧名称を使う)
         CONF_REFPOPUP_BY_MO = 0,    // レス番号の上にマウスオーバーしたときに参照ポップアップ表示する
         CONF_NAMEPOPUP_BY_MO = 0,   // 名前の上にマウスオーバーしたときにポップアップ表示する
         CONF_IDPOPUP_BY_MO = 0,     // IDの上にマウスオーバーしたときにIDをポップアップ表示する
@@ -47,7 +49,7 @@ namespace CONFIG
         CONF_TREE_YPAD = 1,         // ツリービューの行間スペース
         CONF_TREE_SHOW_EXPANDERS = 1, // ツリービューにエクスパンダを表示
         CONF_TREE_LEVEL_INDENT = 0, // ツリービューのレベルインデント調整量(ピクセル)
-        CONF_SCROLL_TREE = 1,       // カテゴリを開いたときにツリービューをスクロールする
+        CONF_SCROLL_TREE = 1,       // カテゴリやディレクトリを開いたときにツリービューをスクロールする
         CONF_SELECT_ITEM_SYNC = 1,  // ツリービューの選択を表示中のビューと同期する ( 0: 同期しない 1: 同期する 2: 同期する(フォルダを開く) )
         CONF_VIEW_MARGIN = 0,       // 各ビューと枠との間の余白
         CONF_LEFT_SCRBAR = 0,       // スクロールバーを左に配置
@@ -66,7 +68,7 @@ namespace CONFIG
         CONF_LIVE_SPEED = 2,        // 実況速度
         CONF_LIVE_THRESHOLD = 10,   // 実況のスクロールモードを切り替えるしきい値
         CONF_OPEN_ONE_CATEGORY = 0, // 板一覧でカテゴリを常にひとつだけ開く
-        CONF_OPEN_ONE_FAVORITE = 0, // お気に入りでカテゴリを常にひとつだけ開く
+        CONF_OPEN_ONE_FAVORITE = 0, // お気に入りでディレクトリを常にひとつだけ開く
         CONF_ALWAYS_WRITE_OK = 0,   // 書き込み時に書き込み確認ダイアログを出さない
         CONF_SAVE_POSTLOG = 0,      //書き込みログを保存
         CONF_SAVE_POSTHIST = 1,      //書き込み履歴を保存
@@ -180,6 +182,7 @@ namespace CONFIG
     };
 
 #define CONF_FONTSIZE_THREAD "12"
+#define CONF_FONTSIZE_MAIL   "12"
 #define CONF_FONTSIZE_POPUP  "10"
 #define CONF_FONTSIZE_TREE   "10"
 
@@ -208,32 +211,24 @@ namespace CONFIG
 // 2chの認証サーバのアドレス
 #define CONF_LOGIN2CH "https://2chv.tora3.net/futen.cgi"
 
-// p2の認証サーバのアドレス
-#define CONF_LOGINP2 "http://p2.2ch.sc/p2/"
-
 // BEの認証サーバのアドレス
 #define CONF_LOGINBE "http://be.2ch.net/test/login.php"
 
 // bbsmenu.htmlのURL
-#define CONF_URL_BBSMENU "http://menu.5ch.net/bbsmenu.html"
+#define CONF_URL_BBSMENU "https://menu.5ch.net/bbsmenu.html"
 
 // スレタイ検索用メニュータイトルアドレス
 #define CONF_MENU_SEARCH_TITLE  "スレタイ検索 (ff5ch.syoboi.jp)"
 #define CONF_URL_SEARCH_TITLE "https://ff5ch.syoboi.jp/?q=$TEXTU"
 
 // スレタイ検索用正規表現
-#define CONF_REGEX_SEARCH_TITLE R"=(<a href="(http[^"]+)">([^<]+)</a><span class="count"> \(([0-9]{1,4})\)</span>)="
+#define CONF_REGEX_SEARCH_TITLE R"=(<a [^>]*?href="(http[^"]+)">([^<]+)</a><span[[:space:]]+class="count"> \(([0-9]+)\))="
 
 // WEB検索用メニュータイトルアドレス
 #define CONF_MENU_SEARCH_WEB  "WEB検索 (google)"
 #define CONF_URL_SEARCH_WEB "http://www.google.co.jp/search?hl=ja&q=$TEXTU&btnG=Google+%E6%A4%9C%E7%B4%A2&lr="
 
-// p2 書き込み用アドレス
-
-#define CONF_URL_WRITEP2 "http://p2.2ch.sc/p2/post_form.php?host=$HOST&bbs=$BBSNAME&key=$DATNAME"
-#define CONF_URL_RESP2 "http://p2.2ch.sc/p2/post_form.php?host=$HOST&bbs=$BBSNAME&key=$DATNAME&popup=1&inyou=2&resnum=$NUMBER"
-
-// 2chのクッキー:HAP
+// 2chのクッキー (互換性のため設定名は旧名称を使う)
 #define CONF_COOKIE_HAP ""
 #define CONF_COOKIE_HAP_BBSPINK ""
 
