@@ -212,9 +212,7 @@ std::string InputDiag::get_key_label()
     for( int mode = CONTROL::MODE_START; mode <= CONTROL::MODE_END; ++mode ){
 
         const std::vector< int > vec_ids = CONTROL::check_key_conflict( mode, m_str_motion );
-        std::vector< int >::const_iterator it = vec_ids.begin();
-        for( ; it != vec_ids.end(); ++it ){
-            const int id = *it;
+        for( const int id : vec_ids ) {
             label += "\n" + CONTROL::get_label( id ) + " ( " + CONTROL::get_mode_label( mode ) + " )";
             if( mode == m_controlmode && id != m_id ) label += " ×";
         }
@@ -232,9 +230,7 @@ std::string InputDiag::get_mouse_label()
     for( int mode = CONTROL::MODE_START; mode <= CONTROL::MODE_END; ++mode ){
 
         const std::vector< int > vec_ids = CONTROL::check_mouse_conflict( mode, m_str_motion );
-        std::vector< int >::const_iterator it = vec_ids.begin();
-        for( ; it != vec_ids.end(); ++it ){
-            const int id = *it;
+        for( const int id : vec_ids ) {
             label += "\n" + CONTROL::get_label( id ) + " ( " + CONTROL::get_mode_label( mode ) + " )";
             if( mode == m_controlmode && id != m_id ) label += " ×";
         }
@@ -251,10 +247,8 @@ std::string InputDiag::get_button_label()
     for( int mode = CONTROL::MODE_START; mode <= CONTROL::MODE_END; ++mode ){
 
         const std::vector< int > vec_ids = CONTROL::check_button_conflict( mode, m_str_motion );
-        std::vector< int >::const_iterator it = vec_ids.begin();
-        for( ; it != vec_ids.end(); ++it ){
-            const int id = *it;
-            label += "\n" + CONTROL::get_label( id ) + " ( " + CONTROL::get_mode_label( mode ) + " )";
+        for( const int id : vec_ids ) {
+            label.append( "\n" + CONTROL::get_label( id ) + " ( " + CONTROL::get_mode_label( mode ) + " )" );
         }
     }
 
@@ -379,15 +373,13 @@ std::string MouseKeyDiag::show_inputdiag( bool is_append )
         // 設定が重複していないかチェック
         bool conflict = false;
         const std::vector< int > vec_ids = check_conflict( m_controlmode, diag->get_str_motion() );
-        std::vector< int >::const_iterator it = vec_ids.begin();
-        for( ; it != vec_ids.end(); ++it ){
-            const int id = *it;
-            if( id != CONTROL::None && id != m_id ){
-                SKELETON::MsgDiag mdiag( nullptr, diag->get_str_motion() + "\n\nは「" + CONTROL::get_label( id ) + "」で使用されています" );
-                mdiag.run();
-                conflict = true;
-                break;
-            }
+        auto it = std::find_if( vec_ids.cbegin(), vec_ids.cend(),
+                                [this]( int id ) { return id != CONTROL::None && id != m_id; } );
+        if( it != vec_ids.cend() ) {
+            const std::string label = CONTROL::get_label( *it );
+            SKELETON::MsgDiag mdiag( nullptr, diag->get_str_motion() + "\n\nは「" + label + "」で使用されています" );
+            mdiag.run();
+            conflict = true;
         }
 
         if( ! conflict ){
@@ -412,7 +404,10 @@ void MouseKeyDiag::slot_row_activated( const Gtk::TreeModel::Path& path, Gtk::Tr
     if( ! row ) return;
 
     std::string str_motion = show_inputdiag( false );
-    if( ! str_motion.empty() ) row[ m_columns.m_col_motion ] = str_motion;
+    if( ! str_motion.empty() ) {
+        row[ m_columns.m_col_motion ] = str_motion;
+        static_cast<void>( row ); // cppcheck: unreadVariable
+    }
 }
 
 
@@ -460,6 +455,7 @@ void MouseKeyDiag::slot_add()
 
     Gtk::TreeModel::iterator it_new = m_liststore->append();
     ( *it_new )[ m_columns.m_col_motion ] = str_motion;
+    static_cast<void>( *it_new ); // cppcheck: unreadVariable
 }
 
 
@@ -475,32 +471,27 @@ void MouseKeyDiag::slot_reset()
     // デフォルト設定が既に使われていないか確認
     std::list< std::string > list_motions = MISC::StringTokenizer( default_motions, ' ' );
     std::list< std::string > list_defaults;
-    std::list< std::string >::iterator it = list_motions.begin();
-    for( ; it != list_motions.end() ; ++it ){
+    for( const std::string& raw_motion : list_motions ) {
 
-        const std::string motion = MISC::remove_space( *it );
+        std::string motion = MISC::remove_space( raw_motion );
 
         bool conflict = false;
         const std::vector< int > vec_ids = check_conflict( m_controlmode, motion );
-        std::vector< int >::const_iterator it = vec_ids.begin();
-        for( ; it != vec_ids.end(); ++it ){
-            const int id = *it;
-
-            if( id != CONTROL::None && id != m_id ){
-                SKELETON::MsgDiag mdiag( nullptr, motion + "\n\nは「" + CONTROL::get_label( id ) + "」で使用されています" );
-                mdiag.run();
-                conflict = true;
-                break;
-            }
+        auto it = std::find_if( vec_ids.cbegin(), vec_ids.cend(),
+                                [this]( int id ) { return id != CONTROL::None && id != m_id; } );
+        if( it != vec_ids.cend() ) {
+            const std::string label = CONTROL::get_label( *it );
+            SKELETON::MsgDiag mdiag( nullptr, motion + "\n\nは「" + label + "」で使用されています" );
+            mdiag.run();
+            conflict = true;
         }
 
-        if( ! conflict ) list_defaults.push_back( motion );
+        if( ! conflict ) list_defaults.push_back( std::move( motion ) );
     }
 
     // クリアして再登録
     m_liststore->clear();
-    it = list_defaults.begin();
-    for( ; it != list_defaults.end() ; ++it ) append_row( ( *it ) );
+    for( const std::string& motion : list_defaults ) append_row( motion );
 }
 
 
@@ -585,6 +576,7 @@ void MouseKeyPref::append_comment_row( const std::string& comment )
         row[ m_columns.m_col_motions ] = std::string();
         row[ m_columns.m_col_id ] = CONTROL::None;
         row[ m_columns.m_col_drawbg ] = false;
+        static_cast<void>( row ); // cppcheck: unreadVariable
     }
 }
 
