@@ -11,6 +11,7 @@
 
 #include <gtkmm.h>
 #include <list>
+#include <memory>
 #include <string>
 
 #include "skeleton/dispatchable.h"
@@ -51,6 +52,11 @@ namespace IMAGE
     class ImageAdmin;
 }
 
+namespace JDLIB
+{
+    class Timeout;
+}
+
 
 namespace MESSAGE
 {
@@ -81,7 +87,7 @@ namespace CORE
         SKELETON::JDHPaned m_hpaned;
 
         // サイドバー
-        Gtk::Widget* m_sidebar;
+        Gtk::Widget* m_sidebar{};
 
         // (縦/横) 3ペーンモード時の右側ペーン
         SKELETON::JDVPaned m_vpaned_r; 
@@ -91,33 +97,35 @@ namespace CORE
         SKELETON::JDVBox m_vbox_article;
         SKELETON::JDVBox m_vbox_toolbar;
         SKELETON::JDNotebook m_notebook_right;
-        bool m_imagetab_shown;
+        bool m_imagetab_shown{};
         SKELETON::JDVPaned m_vpaned_message; // 埋め込み書き込みビュー用
 
         // ツールバー
-        MainToolBar* m_toolbar;
+        MainToolBar* m_toolbar{};
 
         // タイトルに表示する文字列
         // set_maintitle() 参照
         std::string m_title;
 
-        Gtk::MenuBar* m_menubar;
-        Gtk::MenuItem *m_menuitem_prevview;
-        Gtk::MenuItem *m_menuitem_nextview;
+        Gtk::MenuBar* m_menubar{};
+        Gtk::MenuItem* m_menuitem_prevview{};
+        Gtk::MenuItem* m_menuitem_nextview{};
 
         Glib::RefPtr< Gtk::ActionGroup > m_action_group;
         Glib::RefPtr< Gtk::UIManager > m_ui_manager;
         bool m_enable_menuslot;
 
         // 初期設定中
-        bool m_init;
+        bool m_init{};
 
         // セッション保存までのカウンタ
-        int m_count_savesession;
+        int m_count_savesession{};
+
+        std::unique_ptr<JDLIB::Timeout> m_conn_timer;
 
     public:
 
-        Core( JDWinMain& win_main );
+        explicit Core( JDWinMain& win_main );
         ~Core();
 
         Gtk::Widget* get_toplevel();
@@ -242,7 +250,6 @@ namespace CORE
         void slot_toggle_online();
         void slot_toggle_login2ch();
         void slot_toggle_loginbe();
-        void slot_toggle_loginp2();
         void slot_reload_list();
         void slot_quit();
         ///
@@ -296,6 +303,7 @@ namespace CORE
         void slot_setup_key();
         void slot_setup_button();
         void slot_changefont_main();
+        void slot_changefont_mail();
         void slot_changefont_popup();
         void slot_changefont_tree();
         void slot_changecolor_char();
