@@ -117,13 +117,7 @@ ArticleBase::~ArticleBase()
     assert( get_lock() == 0 );
 
     // nodetreeのクリアと情報保存
-    unlock_impl();
-}
-
-
-bool ArticleBase::empty()
-{
-    return  m_url.empty();
+    ArticleBase::unlock_impl();
 }
 
 
@@ -161,7 +155,7 @@ const std::string& ArticleBase::get_since_date()
 int ArticleBase::get_speed()
 {
     time_t current_t = time( nullptr );
-    return ( get_number() * 60 * 60 * 24 ) / MAX( 1, current_t - get_since_time() );
+    return ( static_cast<std::time_t>( get_number() ) * 60 * 60 * 24 ) / MAX( 1, current_t - get_since_time() );
 }
 
 
@@ -287,6 +281,11 @@ std::list< int > ArticleBase::get_res_posted()
     return list_resnum;
 }
 
+// 高参照レスをリストにして取得
+std::list< int > ArticleBase::get_highly_referenced_res()
+{
+    return get_nodetree()->get_highly_referened_res();
+}
 
 //
 // number番のレスを参照しているレス番号をリストにして取得
@@ -340,15 +339,6 @@ std::string ArticleBase::get_res_str( int number, bool ref )
 }
 
 
-//
-// number　番のレスの生文字列を返す
-//
-std::string ArticleBase::get_raw_res_str( int number )
-{
-    return get_nodetree()->get_raw_res_str( number );
-}
-
-
 //
 // 更新時刻
 //
