@@ -6,16 +6,15 @@
 #include "board2ch.h"
 #include "article2ch.h"
 #include "articlehash.h"
+#include "frontloader.h"
 
 #include "config/globalconf.h"
 
 #include "jdlib/miscutil.h"
 #include "jdlib/misctime.h"
-#include "jdlib/jdregex.h"
 
 #include "login2ch.h"
 #include "loginbe.h"
-#include "loginp2.h"
 
 #include <sstream>
 
@@ -31,7 +30,12 @@ Board2ch::Board2ch( const std::string& root, const std::string& path_board, cons
 }
 
 
-Board2ch::~Board2ch() noexcept = default;
+Board2ch::~Board2ch() noexcept
+{
+    if( m_frontloader ) {
+        m_frontloader->terminate_load();
+    }
+}
 
 
 // ユーザエージェント
@@ -44,8 +48,6 @@ const std::string& Board2ch::get_agent()
 // 書き込み用
 const std::string& Board2ch::get_agent_w()
 {
-    if( CORE::get_loginp2()->login_now() ) return CONFIG::get_agent_for_data();
-
     return CONFIG::get_agent_for2ch();
 }
 
@@ -88,12 +90,6 @@ std::string Board2ch::get_proxy_basicauth()
 // 書き込み用プロキシ
 std::string Board2ch::get_proxy_host_w()
 {
-    if( CORE::get_loginp2()->login_now() ){
-
-        if( CONFIG::get_use_proxy_for_data() ) return CONFIG::get_proxy_for_data();
-        else return std::string();
-    }
-
     const int mode = get_mode_local_proxy_w();
 
     if( mode == DBTREE::PROXY_GLOBAL ){
@@ -106,8 +102,6 @@ std::string Board2ch::get_proxy_host_w()
 
 int Board2ch::get_proxy_port_w()
 {
-    if( CORE::get_loginp2()->login_now() ) return CONFIG::get_proxy_port_for_data();
-
     const int mode = get_mode_local_proxy_w();
 
     if( mode == DBTREE::PROXY_GLOBAL ) return CONFIG::get_proxy_port_for2ch_w();
@@ -119,8 +113,6 @@ int Board2ch::get_proxy_port_w()
 
 std::string Board2ch::get_proxy_basicauth_w()
 {
-    if( CORE::get_loginp2()->login_now() ) return CONFIG::get_proxy_basicauth_for_data();
-
     const int mode = get_mode_local_proxy_w();
 
     if( mode == DBTREE::PROXY_GLOBAL ) return CONFIG::get_proxy_basicauth_for2ch_w();
@@ -130,90 +122,121 @@ std::string Board2ch::get_proxy_basicauth_w()
 }
 
 
-//書き込み用クッキー作成
-std::string Board2ch::cookie_for_write()
+// BE 用クッキー作成
+void Board2ch::set_cookie_for_be( std::string& cookie ) const
 {
-#ifdef _DEBUG
-    std::cout << "Board2ch::cookie_for_write\n";
-#endif
-
-    std::string cookie = Board2chCompati::cookie_for_write();
-
-
-    // p2 ログイン中
-    if( CORE::get_loginp2()->login_now() ){
-        if( ! cookie.empty() ) cookie += "; ";
-        cookie += "cid=" + CORE::get_loginp2()->get_sessionid();
-    }
-
     // BE ログイン中
-    else if( CORE::get_loginbe()->login_now() ){
+    if( CORE::get_loginbe()->login_now() ) {
         if( ! cookie.empty() ) cookie += "; ";
         cookie += "DMDM=" + CORE::get_loginbe()->get_sessionid() + "; MDMD=" + CORE::get_loginbe()->get_sessiondata();
     }
+}
+
+
+//
+// 読み込み用クッキー作成
+//
+// プロキシの2ch読み込み用設定がoffのとき
+// またはプロキシにクッキーを送る設定のときは対象サイトにcookieを送信する
+//
+std::string Board2ch::cookie_for_request() const
+{
+    std::string cookie;
+
+    if( ! CONFIG::get_use_proxy_for2ch() || CONFIG::get_send_cookie_to_proxy_for2ch() ) {
+        cookie = cookie_by_host();
+        if( cookie.empty() ) cookie = get_hap();
+    }
+
+    set_cookie_for_be( cookie );
 
 #ifdef _DEBUG
-    std::cout << "cookie = " << cookie << std::endl;
-#endif 
+    std::cout << "Board2ch::cookie_for_request cookie = " << cookie << std::endl;
+#endif
+    return cookie;
+}
 
+
+//
+// 書き込み用クッキー作成
+//
+// プロキシの2ch書き込み用設定がoffのとき
+// またはプロキシにクッキーを送る設定のときは対象サイトにcookieを送信する
+//
+std::string Board2ch::cookie_for_post() const
+{
+    std::string cookie;
+
+    if( ! CONFIG::get_use_proxy_for2ch_w() || CONFIG::get_send_cookie_to_proxy_for2ch_w() ) {
+        cookie = cookie_by_host();
+        if( cookie.empty() ) cookie = get_hap();
+    }
+
+    set_cookie_for_be( cookie );
+
+#ifdef _DEBUG
+    std::cout << "Board2ch::cookie_for_post cookie = " << cookie << std::endl;
+#endif
     return cookie;
 }
 
 
 std::string Board2ch::get_write_referer()
 {
-    // p2ログインの場合はとりあえず空文字
-    if( CORE::get_loginp2()->login_now() ) return std::string();
-
     return Board2chCompati::get_write_referer();
 }
 
 
+// フロントページのダウンロード
+void Board2ch::download_front()
+{
+    if( ! m_frontloader ) m_frontloader.reset( new FrontLoader( url_boardbase() ) );
+    m_frontloader->reset();
+    m_frontloader->download_text();
+}
+
+
 // 新スレ作成時の書き込みメッセージ作成
 std::string Board2ch::create_newarticle_message( const std::string& subject, const std::string& name,
                                                  const std::string& mail, const std::string& msg )
 {
     if( subject.empty() ) return std::string();
     if( msg.empty() ) return std::string();
+    if( ! m_frontloader || m_frontloader->get_data().empty() ) {
+        // フロントページを読み込んでない場合はメッセージ作成を中断してダウンロードする
+        set_keyword_for_write( "" );
+        Board2ch::download_front();
+        return {};
+    }
 
     std::stringstream ss_post;
-    ss_post.clear();
-    ss_post << "bbs="      << get_id()
-            << "&subject=" << MISC::charset_url_encode( subject, get_charset() );
+    ss_post << "submit="   << MISC::charset_url_encode( "新規スレッド作成", get_charset() )
+            << "&subject=" << MISC::charset_url_encode( subject, get_charset() )
+            << "&FROM="    << MISC::charset_url_encode( name, get_charset() )
+            << "&mail="    << MISC::charset_url_encode( mail, get_charset() )
+            << "&MESSAGE=" << MISC::charset_url_encode( msg, get_charset() )
+            << "&bbs="     << get_id()
+            << "&time="    << m_frontloader->get_time_modified();
 
-    // キーワード( hana=mogera や suka=pontan など )
-    const std::string keyword = get_keyword_for_write();
+    // キーワード
+    const std::string keyword = get_keyword_for_newarticle();
     if( ! keyword.empty() ) ss_post << "&" << keyword;
 
     // 2chログイン中
     // sidを送る
-    if( ! CORE::get_loginp2()->login_now() && CORE::get_login2ch()->login_now() ){
+    if( CORE::get_login2ch()->login_now() ){
         std::string sid = CORE::get_login2ch()->get_sessionid();
         ss_post << "&sid=" << MISC::url_encode( sid.c_str(), sid.length() );
     }
 
-    ss_post << "&time="    << get_time_modified()
-            << "&submit="  << MISC::charset_url_encode( "新規スレッド作成", get_charset() )
-            << "&FROM="    << MISC::charset_url_encode( name, get_charset() )
-            << "&mail="    << MISC::charset_url_encode( mail, get_charset() )
-            << "&MESSAGE=" << MISC::charset_url_encode( msg, get_charset() );
-
-    if( CORE::get_loginp2()->login_now() ){
-
-        ss_post << "&detect_hint=" << MISC::charset_url_encode( "◎◇", get_charset() )
-                << "&host=" << MISC::url_encode( MISC::get_hostname( get_root(), false ) )
-                << "&key="
-                << "&popup=1"
-                << "&rescount=1"
-                << "&ttitle_en="
-                << "&csrfid=" << MISC::url_encode( CORE::get_loginp2()->get_sessiondata() )
-                << "&newthread=1";
-    }
-
 #ifdef _DEBUG
     std::cout << "Board2ch::create_newarticle_message " << ss_post.str() << std::endl;
 #endif
 
+    // 書き込みメッセージを作成したらキーワードとフロントページの読み込み状況はリセットする
+    set_keyword_for_write( "" );
+    m_frontloader->reset();
+
     return ss_post.str();
 }
 
@@ -226,8 +249,6 @@ std::string Board2ch::create_newarticle_message( const std::string& subject, con
 //
 std::string Board2ch::url_bbscgi_new()
 {
-    if( CORE::get_loginp2()->login_now() ) return CONFIG::get_url_loginp2() + "post.php";
-
     return Board2chCompati::url_bbscgi_new();
 }
 
@@ -239,8 +260,6 @@ std::string Board2ch::url_bbscgi_new()
 //
 std::string Board2ch::url_subbbscgi_new()
 {
-    if( CORE::get_loginp2()->login_now() ) return CONFIG::get_url_loginp2() + "post.php";
-
     return Board2chCompati::url_subbbscgi_new();
 }
 
@@ -269,8 +288,8 @@ ArticleBase* Board2ch::append_article( const std::string& datbase, const std::st
 
 
 
-// 2chのクッキー:HAP
-std::string Board2ch::get_hap()
+// 2chのクッキー
+std::string Board2ch::get_hap() const
 {
     if( ! CONFIG::get_use_cookie_hap() ) return std::string();
 
@@ -288,46 +307,22 @@ void Board2ch::set_hap( const std::string& hap )
 
 
 //
-// 2chのクッキー:HAPの更新
+// 2chのクッキーの更新
 //
 void Board2ch::update_hap()
 {
     if( ! CONFIG::get_use_cookie_hap() ) return;
 
-    const std::list< std::string > list_cookies = BoardBase::list_cookies_for_write();
-    if( list_cookies.empty() ) return;
+    const std::string new_cookie = Board2chCompati::cookie_for_request();
 
+    if( ! new_cookie.empty() ) {
 #ifdef _DEBUG
-    std::cout << "Board2ch::update_hap\n";
+        const std::string old_cookie = get_hap();
 #endif
-
-    JDLIB::Regex regex;
-    const size_t offset = 0;
-    const bool icase = false;
-    const bool newline = true;
-    const bool usemigemo = false;
-    const bool wchar = false;
-
-    const std::string query_hap = "HAP=([^;]*)?";
-
-    std::list< std::string >::const_iterator it = list_cookies.begin();
-    for( ; it != list_cookies.end(); ++it ){
-
-        const std::string cookie = (*it);
+        set_hap( new_cookie );
 #ifdef _DEBUG
-        std::cout << cookie << std::endl;
+        std::cout << "Board2ch::update_hap old = " << old_cookie << std::endl;
+        std::cout << "Board2ch::update_hap new = " << new_cookie << std::endl;
 #endif
-        if( regex.exec( query_hap, cookie, offset, icase, newline, usemigemo, wchar ) ){
-
-            const std::string tmp_hap = regex.str( 1 );
-            if( ! tmp_hap.empty() && tmp_hap != get_hap() ){
-#ifdef _DEBUG
-                std::cout << "old = " << get_hap() << std::endl;
-                std::cout << "new = " << tmp_hap << std::endl;
-#endif
-                set_hap( tmp_hap );
-                return;
-            }
-        }
     }
 }
