@@ -9,8 +9,13 @@
 
 #include "board2chcompati.h"
 
+#include <memory>
+
+
 namespace DBTREE
 {
+    class FrontLoader;
+
     enum
     {
         DEFAULT_NUMBER_MAX_2CH = 1000,  // デフォルト最大レス数
@@ -19,6 +24,8 @@ namespace DBTREE
 
     class Board2ch : public Board2chCompati
     {
+        std::unique_ptr<FrontLoader> m_frontloader;
+
       public:
 
         Board2ch( const std::string& root, const std::string& path_board,const std::string& name );
@@ -38,12 +45,17 @@ namespace DBTREE
         int get_proxy_port_w() override;
         std::string get_proxy_basicauth_w() override;
 
+        // 読み込み用クッキー
+        std::string cookie_for_request() const override;
         // 書き込み用クッキー
-        std::string cookie_for_write() override;
+        std::string cookie_for_post() const override;
 
         // 書き込み時のリファラ
         std::string get_write_referer() override;
 
+        // フロントページのダウンロード
+        void download_front() override;
+
         // 新スレ作成用のメッセージ変換
         std::string create_newarticle_message( const std::string& subject, const std::string& name,
                                                const std::string& mail, const std::string& msg ) override;
@@ -59,11 +71,11 @@ namespace DBTREE
 
       protected:
 
-        // クッキー:HAP
-        std::string get_hap() override;
+        // クッキー
+        std::string get_hap() const override;
         void set_hap( const std::string& hap ) override;
 
-        // クッキー:HAPの更新 (クッキーをセットした時に実行)
+        // クッキーの更新 (クッキーをセットした時に実行)
         void update_hap() override;
 
       private:
@@ -72,6 +84,8 @@ namespace DBTREE
         int get_default_number_max_res() override { return DEFAULT_NUMBER_MAX_2CH; }
 
         ArticleBase* append_article( const std::string& datbase, const std::string& id, const bool cached ) override;
+
+        void set_cookie_for_be( std::string& cookie ) const;
     };
 }
 
