@@ -87,137 +87,29 @@ bool Board2chCompati::is_valid( const std::string& filename )
 }
 
 
-//書き込み用クッキー作成
-std::string Board2chCompati::cookie_for_write()
-{
-    const std::list< std::string > list_cookies = BoardBase::list_cookies_for_write();
-    if( list_cookies.empty() ) return std::string();
-
-#ifdef _DEBUG
-    std::cout << "Board2chCompati::cookie_for_write\n";
-#endif
-
-    JDLIB::Regex regex;
-    const size_t offset = 0;
-    const bool icase = false;
-    const bool newline = true;
-    const bool usemigemo = false;
-    const bool wchar = false;
-
-    std::string cookie_expire;
-    std::string cookie_path;
-    std::string cookie_pon;
-    std::string cookie_hap = get_hap();
-    std::string cookie_name;
-    std::string cookie_mail;
-
-    const std::string query_expire = "expires=([^;]*)";
-    const std::string query_path = "path=([^;]*)";
-    const std::string query_pon = "PON=([^;]*)?";
-    const std::string query_hap = "HAP=([^;]*)?";
-    const std::string query_name = "NAME=([^;]*)?";
-    const std::string query_mail = "MAIL=([^;]*)?";
-
-    bool use_pon = false;
-    bool use_hap = ! cookie_hap.empty();
-    bool use_name = false;
-    bool use_mail = false;
-
-    std::list< std::string >::const_iterator it = list_cookies.begin();
-
-    // expire と path は一つ目のcookieから取得
-    if( regex.exec( query_expire, (*it), offset, icase, newline, usemigemo, wchar ) ) cookie_expire = regex.str( 1 );
-    if( regex.exec( query_path, (*it), offset, icase, newline, usemigemo, wchar ) ) cookie_path = regex.str( 1 );
-
-    for( ; it != list_cookies.end(); ++it ){
-
-        const std::string tmp_cookie = MISC::Iconv( (*it), get_charset(), "UTF-8" );
-
-#ifdef _DEBUG
-        std::cout << tmp_cookie << std::endl;
-#endif
-
-        if( regex.exec( query_pon, tmp_cookie, offset, icase, newline, usemigemo, wchar ) ){
-            use_pon = true;
-            cookie_pon = regex.str( 1 );
-        }
-        if( ! use_hap && regex.exec( query_hap, tmp_cookie, offset, icase, newline, usemigemo, wchar ) ){
-            use_hap = true;
-            cookie_hap = regex.str( 1 );
-        }
-        if( regex.exec( query_name, tmp_cookie, offset, icase, newline, usemigemo, wchar ) ){
-            use_name = true;
-            cookie_name = MISC::charset_url_encode( regex.str( 1 ), get_charset() );
-        }
-        if( regex.exec( query_mail, tmp_cookie, offset, icase, newline, usemigemo, wchar ) ){
-            use_mail = true;
-            cookie_mail = MISC::charset_url_encode( regex.str( 1 ), get_charset() );
-        }
-    }
-
-    // PONを取得していないときはHAPを送らない
-    if( ! use_pon || cookie_pon.empty() ){
-        use_hap = false;
-        cookie_hap = std::string();
-    }
-
-#ifdef _DEBUG
-    std::cout << "expire = " << cookie_expire << std::endl
-              << "path = " << cookie_path << std::endl    
-              << "pon = " << cookie_pon << " " << use_pon << std::endl
-              << "hap = " << cookie_hap << " " << use_hap << std::endl
-              << "name = " << cookie_name << " " << use_name << std::endl
-              << "mail = " << cookie_mail << " " << use_mail << std::endl;
-#endif    
-
-    std::string cookie;
-
-    if( use_pon ) cookie += "PON=" + cookie_pon + "; ";
-    if( use_hap ) cookie += "HAP=" + cookie_hap + "; ";
-    if( use_name ) cookie += "NAME=" + cookie_name + "; ";
-    if( use_mail ) cookie += "MAIL=" + cookie_mail + "; ";
-
-    if( cookie.empty() ) return std::string();
-
-    cookie += "expires=" + cookie_expire + "; path=" + cookie_path;
-
-#ifdef _DEBUG
-    std::cout << "cookie = " << cookie << std::endl;
-#endif 
-
-    return cookie;
-}
-
-
-// 書き込み時に必要なキーワード( hana=mogera や suka=pontan など )を
-// 確認画面のhtmlから解析する      
-void Board2chCompati::analyze_keyword_for_write( const std::string& html )
+std::string Board2chCompati::analyze_keyword_impl( const std::string& html )
 {
     std::string keyword;
 
-#ifdef _DEBUG
-    std::cout << "Board2chCompati::analyze_keyword_for_write\n";
-    std::cout << html << std::endl << "--------------------\n";
-#endif
-
     JDLIB::Regex regex;
-    size_t offset = 0;
-    const bool icase = true; // 大文字小文字区別しない
-    const bool newline = false;  // . に改行をマッチさせる
-    const bool usemigemo = false;
-    const bool wchar = false;
+    std::size_t offset = 0;
+    constexpr bool icase = true; // 大文字小文字区別しない
+    constexpr bool newline = false;  // . に改行をマッチさせる
+    constexpr bool usemigemo = false;
+    constexpr bool wchar = false;
 
     for(;;){
 
         // <input type=hidden> のタグを解析して name と value を取得
-        if( ! regex.exec( "<input +type=hidden +name=([^ ]*) +value=([^>]*)>", html, offset, icase, newline, usemigemo, wchar ) ) break;
+        constexpr const char regex_input[] = R"(<input +type=("hidden"|hidden) +name=([^ ]*) +value=([^>]*)>)";
+        if( ! regex.exec( regex_input, html, offset, icase, newline, usemigemo, wchar ) ) break;
 
-        offset = html.find( regex.str( 0 ) );
+        offset = regex.pos( 0 );
 
-        std::string name = MISC::remove_space( regex.str( 1 ) );
+        std::string name = MISC::remove_space( regex.str( 2 ) );
         if( name[ 0 ] == '\"' ) name = MISC::cut_str( name, "\"", "\"" );
 
-        std::string value = MISC::remove_space( regex.str( 2 ) );
+        std::string value = MISC::remove_space( regex.str( 3 ) );
         if( value[ 0 ] == '\"' ) value = MISC::cut_str( value, "\"", "\"" );
 
 #ifdef _DEBUG
@@ -244,13 +136,40 @@ void Board2chCompati::analyze_keyword_for_write( const std::string& html )
     }
 
 #ifdef _DEBUG
-    std::cout << "keyword = " << keyword << std::endl;
+    std::cout << "Board2chCompati::analyze_keyword_impl keyword = " << keyword << std::endl;
 #endif
 
+    return keyword;
+}
+
+
+// 書き込み時に必要なキーワード( hana=mogera や suka=pontan など )を
+// 確認画面のhtmlから解析する
+void Board2chCompati::analyze_keyword_for_write( const std::string& html )
+{
+#ifdef _DEBUG
+    std::cout << "Board2chCompati::analyze_keyword_for_write\n";
+    std::cout << html << std::endl << "--------------------\n";
+#endif
+
+    std::string keyword = analyze_keyword_impl( html );
     set_keyword_for_write( keyword );
 }
 
 
+// スレ立て時に必要なキーワードをフロントページのhtmlから解析する
+void Board2chCompati::analyze_keyword_for_newarticle( const std::string& html )
+{
+#ifdef _DEBUG
+    std::cout << "Board2chCompati::analyze_keyword_for_newarticle\n";
+    std::cout << html << std::endl << "--------------------\n";
+#endif
+
+    std::string keyword = analyze_keyword_impl( html );
+    set_keyword_for_newarticle( keyword );
+}
+
+
 // 新スレ作成時の書き込みメッセージ作成
 std::string Board2chCompati::create_newarticle_message( const std::string& subject,
                                                        const std::string& name, const std::string& mail, const std::string& msg )
@@ -343,7 +262,6 @@ void Board2chCompati::parse_subject( const char* str_subject_txt )
         int lng_id_dat = 0;
         const char* str_subject;
         int lng_subject = 0;
-        char str_num[ 16 ];
 
         while( *pos == ' ' ) ++pos;
 
@@ -382,21 +300,20 @@ void Board2chCompati::parse_subject( const char* str_subject_txt )
             break;
         }
         lng_subject = ( int )( pos - str_subject );
-        
-        // レス数取得
+
+        // レス数取得 (符号付き32bit整数より大きいと未定義)
         ++pos;
-        int i = 0;
-        while( '0' <= *pos && *pos <= '9' && i < 16 ) str_num[ i++ ] = *( pos++ );
+        std::string str_num;
+        while( '0' <= *pos && *pos <= '9' ) str_num.push_back( *( pos++ ) );
 
         // 壊れてる
-        if( i == 0 ){
+        if( str_num.empty() ){
             MISC::ERRMSG( "subject.txt is broken (res)" );
             break;
         }
         if( *pos == '\0' ) break;
         if( *pos == '\n' ) { ++pos; continue; }
 
-        str_num[ i ] = '\0';
         ++pos;
 
         // id, subject, number 取得
@@ -414,7 +331,7 @@ void Board2chCompati::parse_subject( const char* str_subject_txt )
             artinfo.subject = MISC::replace_str( artinfo.subject, "&gt;", ">" );
         }
 
-        const auto num = std::atoi( str_num );
+        const auto num = std::atoi( str_num.c_str() );
         artinfo.number = ( num < CONFIG::get_max_resnumber() ) ? num : CONFIG::get_max_resnumber();
 
         get_list_artinfo().push_back( artinfo );
