@@ -24,13 +24,13 @@ namespace DBTREE
         Board2chCompati( const std::string& root, const std::string& path_board, const std::string& name, const std::string& basicauth );
         ~Board2chCompati();
 
-        // 書き込み用クッキー
-        std::string cookie_for_write() override;
-
         // 書き込み時に必要なキーワード( hana=mogera や suka=pontan など )を
         // 確認画面のhtmlから解析する      
         void analyze_keyword_for_write( const std::string& html ) override;
 
+        // スレ立て時に必要なキーワードをフロントページのhtmlから解析する
+        void analyze_keyword_for_newarticle( const std::string& html ) override;
+
         // 新スレ作成用のメッセージ変換
         std::string create_newarticle_message( const std::string& subject, const std::string& name,
                                                const std::string& mail, const std::string& msg ) override;
@@ -64,6 +64,9 @@ namespace DBTREE
 
         // レス数であぼーん(グローバル)
         int get_abone_number_global() override;
+
+        // htmlからキーワードを解析する
+        std::string analyze_keyword_impl( const std::string& html );
     };
 }
 
