@@ -11,6 +11,7 @@
 
 #include "skeleton/msgdiag.h"
 
+#include "jdlib/cookiemanager.h"
 #include "jdlib/jdiconv.h"
 #include "jdlib/jdregex.h"
 #include "jdlib/miscutil.h"
@@ -274,67 +275,72 @@ std::string BoardBase::get_unicode()
 }
 
 
-//書き込み用クッキー
-std::string BoardBase::cookie_for_write()
+// 板のホストを指定してクッキーを取得
+std::string BoardBase::cookie_by_host() const
 {
-    if( m_list_cookies_for_write.empty() ) return std::string();
+    const JDLIB::CookieManager* cookie_manager = JDLIB::get_cookie_manager();
+    const std::string hostname = MISC::get_hostname( get_root(), false );
 
-    return *(m_list_cookies_for_write.begin() );
+    return cookie_manager->get_cookie_by_host( hostname );
 }
 
 
-//書き込み用クッキーのセット
-void BoardBase::set_list_cookies_for_write( const std::list< std::string >& list_cookies )
+//
+// 読み込み用クッキー作成
+//
+// プロキシの読み込み用設定がoffのとき
+// またはプロキシにクッキーを送る設定がonのときはサイトにcookieを送信する
+//
+std::string BoardBase::cookie_for_request() const
 {
-#ifdef _DEBUG
-    std::cout << "BoardBase::set_list_cookies_for_write\n";
-#endif
+    std::string cookie;
 
-    std::list< std::string >::const_iterator it = list_cookies.begin();
-    for( ; it != list_cookies.end(); ++it ){
-
-        const std::string cookie = MISC::remove_space( *it );
-
-#ifdef _DEBUG        
-        std::cout << "cookie = " << cookie << std::endl;
-#endif
-
-        std::string key;
-        const size_t n = cookie.find( '=' );
-        if( n != std::string::npos ) key = cookie.substr( 0, n+1 );
-
-        // 更新
-        // クッキーの削除は未実装
-        if( ! key.empty() && key.find( ";" ) == std::string::npos ){
-             
-#ifdef _DEBUG        
-            std::cout << "key = " << key << std::endl;
-#endif
-            std::list< std::string >::iterator it2 = m_list_cookies_for_write.begin();
-            for( ; it2 != m_list_cookies_for_write.end(); ++it2 ){
-
-                if( (*it2).find( key ) == 0 ){
-#ifdef _DEBUG        
-                    std::cout << "found\n";
-#endif
-                    (*it2) = cookie;
-                    break;
-                }
-            }
-            if( it2 == m_list_cookies_for_write.end() ) m_list_cookies_for_write.push_back( cookie );
-        }
+    if( ! CONFIG::get_use_proxy_for_data() || CONFIG::get_send_cookie_to_proxy_for_data() ) {
+        cookie = cookie_by_host();
     }
+    return cookie;
+}
 
-#ifdef _DEBUG        
-    std::cout << "result:\n";
-    it = m_list_cookies_for_write.begin();
-    for( ; it != m_list_cookies_for_write.end(); ++it ) std::cout << (*it) << std::endl;
-#endif
+
+//
+// 書き込み用クッキー作成
+//
+// プロキシの書き込み用設定がoffのとき
+// またはプロキシにクッキーを送る設定がonのときはサイトにcookieを送信する
+//
+std::string BoardBase::cookie_for_post() const
+{
+    std::string cookie;
+
+    if( ! CONFIG::get_use_proxy_for_data() || CONFIG::get_send_cookie_to_proxy_for_data() ) {
+        cookie = cookie_by_host();
+    }
+    return cookie;
+}
+
+
+// 板のホストを指定してクッキーを追加
+void BoardBase::set_list_cookies( const std::list< std::string >& list_cookies )
+{
+    JDLIB::CookieManager* cookie_manager = JDLIB::get_cookie_manager();
+    const std::string hostname = MISC::get_hostname( get_root(), false );
+
+    for( const std::string& input : list_cookies ) {
+        cookie_manager->feed( hostname, MISC::remove_space( input ) );
+    }
 
     update_hap();
 }
 
 
+// 板のホストを指定してクッキーを削除
+void BoardBase::delete_cookies()
+{
+    JDLIB::CookieManager* cookie_manager = JDLIB::get_cookie_manager();
+    const std::string hostname = MISC::get_hostname( get_root(), false );
+    cookie_manager->delete_cookie_by_host( hostname );
+}
+
 
 void BoardBase::clear()
 {
@@ -1062,6 +1068,7 @@ void BoardBase::create_loaderdata( JDLIB::LOADERDATA& data )
     data.timeout = CONFIG::get_loader_timeout();
     data.basicauth = get_basicauth();
     data.modified = get_date_modified();
+    data.cookie_for_request = cookie_for_request();
 }
 
 
@@ -1144,7 +1151,18 @@ void BoardBase::receive_finish()
         set_date_modified( std::string() );
         send_update_board();
 
-        if( !m_rawdata.empty() && get_code() == HTTP_OK
+        // Locationヘッダーで移転先を指定された場合
+        if( get_code() == HTTP_MOVED_PERM && ! location().empty() ) {
+
+            // location() は url_boardbase() の移転先 (start_checkking_if_board_moved() を参照)
+            if( DBTREE::move_board( url_boardbase(), location() ) ) {
+                // 再読み込み
+                const std::string str_tab = "false";
+                CORE::core_set_command( "open_board", url_subject(), str_tab );
+            }
+        }
+        // HTMLの埋め込みスクリプトで移動を指示された場合
+        else if( !m_rawdata.empty() && get_code() == HTTP_OK
                 && m_rawdata.find( "window.location.href" ) != std::string::npos ) {
 
 #ifdef _DEBUG
@@ -1435,6 +1453,7 @@ bool BoardBase::start_checkking_if_board_moved()
     JDLIB::LOADERDATA data;
     data.init_for_data();
     data.url = url_boardbase();
+    data.cookie_for_request = cookie_for_request();
 
     if( start_load( data ) ){
         m_read_url_boardbase = true;
@@ -1944,7 +1963,6 @@ std::string BoardBase::import_dat( const std::string& filename )
         return std::string();
     }
 
-    const std::string dir = MISC::get_dir( filename );
     const std::string id = MISC::get_filename( filename );
     if( id.empty() || ! is_valid( id ) ){
         SKELETON::MsgDiag mdiag( nullptr, "ファイル名が正しくありません" );
@@ -2129,7 +2147,7 @@ void BoardBase::save_jdboard_info()
 #endif
 
     // あぼーん情報
-    std::string str_abone_id = MISC::listtostr( m_list_abone_id );
+//    std::string str_abone_id = MISC::listtostr( m_list_abone_id );
     std::string str_abone_name = MISC::listtostr( m_list_abone_name );
     std::string str_abone_word = MISC::listtostr( m_list_abone_word );
     std::string str_abone_regex = MISC::listtostr( m_list_abone_regex );
@@ -2353,8 +2371,10 @@ std::list< std::string > BoardBase::get_check_update_articles()
     if( empty() ) return list_url;
     if( is_loading() ) return list_url;
     if( m_status & STATUS_UPDATE ) return list_url;
-    if( ! m_list_subject_created ) download_subject( std::string(), true );
-    if( ! m_list_subject_created ) return list_url;
+    if( ! m_list_subject_created ) {
+        download_subject( std::string(), true );
+        return list_url;
+    }
 
 #ifdef _DEBUG
     std::cout << "BoardBase::get_check_update_articles url = " << url_boardbase() << std::endl;
