@@ -188,13 +188,14 @@ namespace DBTREE
         // 移転を調査するために url_boardbase を読んでいる
         bool m_read_url_boardbase;
 
-        // クッキー, 書き込み時に必要
-        std::list< std::string > m_list_cookies_for_write;
-
         // 書き込み時に必要なキーワード( hana=mogera や suka=pontan など )
         // 書き込み時のメッセージに付加する
         std::string m_keyword_for_write;   
 
+        // スレ立て時に必要なキーワード
+        // スレ立て時のメッセージに付加する
+        std::string m_keyword_for_newarticle;
+
         // basic 認証用の「ユーザID:パスワード」の組
         std::string m_basicauth;
 
@@ -234,11 +235,11 @@ namespace DBTREE
         // m_url_update_views に登録されている view に update_board コマンドを送る
         void send_update_board();
 
-        // クッキー:HAP
-        virtual std::string get_hap(){ return std::string(); }
+        // クッキー
+        virtual std::string get_hap() const { return {}; }
         virtual void set_hap( const std::string& hap ){}
 
-        // クッキー:HAPの更新 (クッキーをセットした時に実行)
+        // クッキーの更新 (クッキーをセットした時に実行)
         virtual void update_hap(){}
 
       public:
@@ -327,21 +328,30 @@ namespace DBTREE
         // 特殊文字書き込み可能か( pass なら可能、 change なら不可 )
         virtual std::string get_unicode();
 
-        // 書き込み用クッキー
-        virtual std::string cookie_for_write();
-        const std::list< std::string >& list_cookies_for_write() { return m_list_cookies_for_write; }
-        void set_list_cookies_for_write( const std::list< std::string >& list_cookies );
-        void reset_list_cookies_for_write(){ m_list_cookies_for_write.clear(); }
+        // 板のホストを指定してクッキーのやり取り
+        std::string cookie_by_host() const;
+        virtual std::string cookie_for_request() const;
+        virtual std::string cookie_for_post() const;
+        void set_list_cookies( const std::list< std::string >& list_cookies );
+        void delete_cookies();
 
         // 書き込み時に必要なキーワード( hana=mogera や suka=pontan など )
         // 書き込み時のメッセージに付加する
         const std::string& get_keyword_for_write() const { return m_keyword_for_write; }
         void set_keyword_for_write( const std::string& keyword ){ m_keyword_for_write = keyword; }
 
+        // スレ立て時に必要なキーワード
+        // スレ立て時のメッセージに付加する
+        const std::string& get_keyword_for_newarticle() const { return m_keyword_for_newarticle; }
+        void set_keyword_for_newarticle( const std::string& keyword ){ m_keyword_for_newarticle = keyword; }
+
         // 書き込み時に必要なキーワード( hana=mogera や suka=pontan など )を
         // 確認画面のhtmlから解析する      
         virtual void analyze_keyword_for_write( const std::string& html ){}
 
+        // スレ立て時に必要なキーワードをフロントページのhtmlから解析する
+        virtual void analyze_keyword_for_newarticle( const std::string& html ) {}
+
         // 書き込み時のリファラ
         virtual std::string get_write_referer(){ return url_boardbase(); }
 
@@ -402,6 +412,9 @@ namespace DBTREE
         // article クラスのポインタ取得
         ArticleBase* get_article_fromURL( const std::string& url );
 
+        // フロントページのダウンロード
+        virtual void download_front() {}
+
         // subject.txt ダウンロード
         // url_update_view : CORE::core_set_command( "update_board" ) を送信するビューのアドレス
         // read_from_cache : まだスレ一覧を開いていないときにキャッシュのsubject.txtを読み込む
