@@ -298,26 +298,32 @@ std::string DBTREE::board_charset( const std::string& url )
 }
 
 
-std::string DBTREE::board_cookie_for_write( const std::string& url )
+std::string DBTREE::board_cookie_by_host( const std::string& url )
 {
-    return DBTREE::get_board( url )->cookie_for_write();
+    return DBTREE::get_board( url )->cookie_by_host();
 }
 
 
-const std::list< std::string >& DBTREE::board_list_cookies_for_write( const std::string& url )
+std::string DBTREE::board_cookie_for_request( const std::string& url )
 {
-    return DBTREE::get_board( url )->list_cookies_for_write();
+    return DBTREE::get_board( url )->cookie_for_request();
 }
 
 
-void DBTREE::board_set_list_cookies_for_write( const std::string& url, const std::list< std::string>& list_cookies )
+std::string DBTREE::board_cookie_for_post( const std::string& url )
 {
-    DBTREE::get_board( url )->set_list_cookies_for_write( list_cookies );
+    return DBTREE::get_board( url )->cookie_for_post();
 }
 
-void DBTREE::board_reset_list_cookies_for_write( const std::string& url )
+
+void DBTREE::board_set_list_cookies( const std::string& url, const std::list< std::string>& list_cookies )
 {
-    DBTREE::get_board( url )->reset_list_cookies_for_write();
+    DBTREE::get_board( url )->set_list_cookies( list_cookies );
+}
+
+void DBTREE::board_delete_cookies( const std::string& url )
+{
+    DBTREE::get_board( url )->delete_cookies();
 }
 
 std::string DBTREE::board_keyword_for_write( const std::string& url )
@@ -338,6 +344,24 @@ void DBTREE::board_analyze_keyword_for_write( const std::string& url, const std:
 }
 
 
+std::string DBTREE::board_keyword_for_newarticle( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_keyword_for_newarticle();
+}
+
+
+void DBTREE::board_set_keyword_for_newarticle( const std::string& url, const std::string& keyword )
+{
+    DBTREE::get_board( url )->set_keyword_for_newarticle( keyword );
+}
+
+
+void DBTREE::board_analyze_keyword_for_newarticle( const std::string& url, const std::string& html )
+{
+    DBTREE::get_board( url )->analyze_keyword_for_newarticle( html );
+}
+
+
 std::string DBTREE::board_basicauth( const std::string& url )
 {
     return DBTREE::get_board( url )->get_basicauth();
@@ -374,6 +398,12 @@ void DBTREE::board_save_info( const std::string& url )
 }
 
 
+void DBTREE::board_download_front( const std::string& url )
+{
+    DBTREE::get_board( url )->download_front();
+}
+
+
 void DBTREE::board_download_subject( const std::string& url, const std::string& url_update_view )
 {
     DBTREE::get_board( url )->download_subject( url_update_view, false );
