@@ -103,19 +103,24 @@ namespace DBTREE
     std::string board_name( const std::string& url );
     std::string board_subjecttxt( const std::string& url );
     std::string board_charset( const std::string& url );
-    std::string board_cookie_for_write( const std::string& url );
-    const std::list< std::string >& board_list_cookies_for_write( const std::string& url );
-    void board_set_list_cookies_for_write( const std::string& url, const std::list< std::string>& list_cookies );
-    void board_reset_list_cookies_for_write( const std::string& url );
+    std::string board_cookie_by_host( const std::string& url );
+    std::string board_cookie_for_request( const std::string& url );
+    std::string board_cookie_for_post( const std::string& url );
+    void board_set_list_cookies( const std::string& url, const std::list< std::string>& list_cookies );
+    void board_delete_cookies( const std::string& url );
     std::string board_keyword_for_write( const std::string& url );
     void board_set_keyword_for_write( const std::string& url, const std::string& keyword );
     void board_analyze_keyword_for_write( const std::string& url, const std::string& html );
+    std::string board_keyword_for_newarticle( const std::string& url );
+    void board_set_keyword_for_newarticle( const std::string& url, const std::string& keyword );
+    void board_analyze_keyword_for_newarticle( const std::string& url, const std::string& html );
     std::string board_basicauth( const std::string& url );
     std::string board_ext( const std::string& url );
     int board_status( const std::string& url );
     int board_code( const std::string& url );
     std::string board_str_code( const std::string& url );
     void board_save_info( const std::string& url );
+    void board_download_front( const std::string& url );
     void board_download_subject( const std::string& url, const std::string& url_update_view );
     void board_read_subject_from_cache( const std::string& url );
     bool board_is_loading( const std::string& url );
