@@ -8,6 +8,7 @@
 #define _NODETREEBASE_H
 
 #include "node.h"
+#include "fontid.h"
 
 #include "skeleton/loadable.h"
 
@@ -109,10 +110,9 @@ namespace DBTREE
         std::map< int, std::vector< int > > m_map_future_refer;
 
         // ロード用変数
-        char* m_buffer_lines;
-        size_t m_byte_buffer_lines_left;
-        char* m_parsed_text;
-        char* m_buffer_write; // 書き込みチェック用バッファ
+        std::string m_buffer_lines;
+        std::string m_parsed_text; // HTMLパーサに使うバッファ
+        std::string m_buffer_write; // 書き込みチェック用バッファ
         bool m_check_update; // HEADによる更新チェックのみ
         bool m_check_write; // 自分の書き込みかチェックする
         bool m_loading_newthread; // 新スレ読み込み中
@@ -207,6 +207,9 @@ namespace DBTREE
         // res_num に含まれるレスを参照しているレス番号をリストにして取得
         std::list< int > get_res_reference( const std::list< int >& res_num );
 
+        // 高参照レスの番号をリストにして取得
+        std::list< int > get_highly_referened_res();
+
         // query を含むレス番号をリストにして取得
         // mode_or == true なら OR抽出
         std::list< int > get_res_query( const std::string& query, const bool mode_or );
@@ -216,9 +219,6 @@ namespace DBTREE
         // ref == true なら先頭に ">" を付ける        
         std::string get_res_str( int number, bool ref = false );
 
-        // number　番のレスの生文字列を返す
-        std::string get_raw_res_str( int number );
-        
         // 明示的にhtml を加える
         // パースして追加したノードのポインタを返す
         // html は UTF-8　であること
@@ -293,17 +293,19 @@ namespace DBTREE
         NODE* create_node_br();
         NODE* create_node_hr();
         NODE* create_node_space( const int type );
-        NODE* create_node_multispace( const char* text, const int n );
+        NODE* create_node_multispace( const char* text, const int n, const char fontid = FONT_MAIN );
         NODE* create_node_htab();
-        NODE* create_node_link( const char* text, const int n, const char* link, const int n_link, const int color_text, const bool bold );
+        NODE* create_node_link( const char* text, const int n, const char* link, const int n_link, const int color_text, const bool bold, const char fontid = FONT_MAIN );
         NODE* create_node_anc( const char* text, const int n, const char* link, const int n_link,
                                const int color_text, const bool bold,
-                               const ANCINFO* ancinfo, const int lng_ancinfo );
+                               const ANCINFO* ancinfo, const int lng_ancinfo, const char fontid = FONT_MAIN );
         NODE* create_node_sssp( const char* link, const int n_link );
-        NODE* create_node_img( const char* text, const int n, const char* link, const int n_link, const int color_text, const bool bold );
-        NODE* create_node_text( const char* text, const int color_text, const bool bold = false );
-        NODE* create_node_ntext( const char* text, const int n, const int color_text, const bool bold = false );
-        NODE* create_node_thumbnail( const char* text, const int n, const char* link, const int n_link, const char* thumb, const int n_thumb, const int color_text, const bool bold );
+        NODE* create_node_img( const char* text, const int n, const char* link, const int n_link, const int color_text,
+                               const bool bold, const char fontid = FONT_MAIN );
+        NODE* create_node_text( const char* text, const int color_text, const bool bold = false, const char fontid = FONT_MAIN );
+        NODE* create_node_ntext( const char* text, const int n, const int color_text, const bool bold = false, const char fontid = FONT_MAIN );
+        NODE* create_node_thumbnail( const char* text, const int n, const char* link, const int n_link, const char* thumb, const int n_thumb,
+                                     const int color_text, const bool bold, const char fontid = FONT_MAIN );
 
         // 以下、構文解析用関数
         void add_raw_lines( char* rawines, size_t size );
@@ -319,11 +321,11 @@ namespace DBTREE
         // bold : ボールド表示
         // ahref : <a href=～></a> からリンクノードを作成する
         void parse_html( const char* str, const int lng, const int color_text,
-                         bool digitlink, const bool bold, const bool ahref );
+                         bool digitlink, const bool bold, const bool ahref, const char fontid = FONT_MAIN );
 
         // 書き込みログ比較用文字列作成
         // m_buffer_write に作成した文字列をセットする
-        void parse_write( const char* str, const int lng, const int max_lng_write );
+        void parse_write( const char* str, const int lng, const std::size_t max_lng_write );
 
         bool check_anchor( const int mode, const char* str_in, int& n, char* str_out, char* str_link, int lng_link, ANCINFO* ancinfo );
         int check_link( const char* str_in, const int lng_in, int& n_in, char* str_link, const int lng_link );
