@@ -11,6 +11,7 @@
 #include "boardbase.h"
 #include "articlebase.h"
 
+#include "jdlib/cookiemanager.h"
 #include "jdlib/jdiconv.h"
 #include "jdlib/jdregex.h"
 #include "jdlib/miscutil.h"
@@ -183,10 +184,8 @@ BoardBase* Root::get_board( const std::string& url, const int count )
     }
 
     // サーチ
-    std::list< BoardBase* >::iterator it;
-    for( it = m_list_board.begin(); it != m_list_board.end(); ++it ){
+    for( BoardBase* board : m_list_board ) {
 
-        BoardBase* board = *( it );
         if( board->equal( url ) ){
 
             board->read_info(); // 板情報の取得( 詳しくはBoardBase::read_info()をみること )
@@ -214,38 +213,41 @@ BoardBase* Root::get_board( const std::string& url, const int count )
         // 2ch型の場合、板パスを見てもし一致したら新ホストに移転したと判断して移転テーブルを更新する
         if( is_2ch( url ) ){
 
+            // 板パスを見て一致したら移転したと見なす
+            // TODO : 板パスが同じ板が2つ以上あるときどうするか？
+            const auto match_path = [&url, this]( const BoardBase* b ) {
+                return is_2ch( b->get_root() ) && url.find( b->get_path_board() + "/" ) != std::string::npos;
+            };
+
             // 全ての板をサーチして移転先の板を探す
-            std::list< BoardBase* >::iterator it;
-            for( it = m_list_board.begin(); it != m_list_board.end(); ++it ){
+            auto it = std::find_if( m_list_board.begin(), m_list_board.end(), match_path );
+            if( it != m_list_board.end() ) {
+                BoardBase* board = *it;
 
-                BoardBase* board = *( it );
+                const std::string hostname = MISC::get_hostname( url );
+                const std::string& path_board = board->get_path_board();
 
-                // 板パスを見て一致したら移転したと見なす
-                // TODO : 板パスが同じ板が2つ以上あるときどうするか？
-                if( is_2ch( board->get_root() ) && url.find( board->get_path_board() + "/" ) != std::string::npos ){
+                // 板移転テーブルを更新
+                push_movetable( hostname, path_board, board->get_root(), path_board );
 
-                    // 板移転テーブルを更新
-                    push_movetable( MISC::get_hostname( url ), board->get_path_board(), board->get_root(), board->get_path_board() );
-                    
-                    std::ostringstream ss;
-                    ss << board->get_name() << std::endl
-                       << "旧 URL = " << MISC::get_hostname( url ) + board->get_path_board() << "/" << std::endl
-                       << "新 URL  = " << board->url_boardbase() << std::endl;
-                    MISC::MSG( ss.str() );
+                std::ostringstream ss;
+                ss << board->get_name() << '\n'
+                   << "旧 URL = " << hostname + path_board << '/' << '\n'
+                   << "新 URL  = " << board->url_boardbase() << std::endl;
+                MISC::MSG( ss.str() );
 
-                    if( m_enable_save_movetable ){
+                if( m_enable_save_movetable ){
 
-                        //移転テーブル保存
-                        save_movetable();
+                    //移転テーブル保存
+                    save_movetable();
 
-                        // サイドバーに登録されているURL更新
-                        CORE::core_set_command( "update_sidebar_item" );
-                    }
-
-                    BoardBase* board = get_board( url, count + 1 );
-                    m_get_board_url = url;
-                    return board;
+                    // サイドバーに登録されているURL更新
+                    CORE::core_set_command( "update_sidebar_item" );
                 }
+
+                board = get_board( url, count + 1 );
+                m_get_board_url = url;
+                return board;
             }
         }
 
@@ -310,6 +312,36 @@ void Root::download_bbsmenu()
     data.url = CONFIG::get_url_bbsmenu();
     data.modified = get_date_modified();
 
+    bool send_cookie = true;
+
+    constexpr bool protocol = false;
+    const std::string host = MISC::get_hostname( data.url, protocol );
+    if( host.find( ".5ch.net" ) != std::string::npos || host.find( ".2ch.net" ) != std::string::npos ) {
+        data.agent = CONFIG::get_agent_for2ch();
+        if( CONFIG::get_use_proxy_for2ch() ) {
+            data.host_proxy = CONFIG::get_proxy_for2ch();
+            data.port_proxy = CONFIG::get_proxy_port_for2ch();
+            data.basicauth_proxy = CONFIG::get_proxy_basicauth_for2ch();
+            data.basicauth = CONFIG::get_proxy_basicauth_for2ch();
+            send_cookie = CONFIG::get_send_cookie_to_proxy_for2ch();
+        }
+    }
+    else {
+        data.agent = CONFIG::get_agent_for_data();
+        if( CONFIG::get_use_proxy_for_data() ) {
+            data.host_proxy = CONFIG::get_proxy_for_data();
+            data.port_proxy = CONFIG::get_proxy_port_for_data();
+            data.basicauth_proxy = CONFIG::get_proxy_basicauth_for_data();
+            data.basicauth = CONFIG::get_proxy_basicauth_for_data();
+            send_cookie = CONFIG::get_send_cookie_to_proxy_for_data();
+        }
+    }
+
+    if( send_cookie ) {
+        const JDLIB::CookieManager* cookie_manager = JDLIB::get_cookie_manager();
+        data.cookie_for_request = cookie_manager->get_cookie_by_host( data.url );
+    }
+
     start_load( data );
 }
 
@@ -347,6 +379,19 @@ void Root::receive_finish()
         return;
     }
 
+    if( get_code() == HTTP_MOVED_PERM && ! location().empty() ){
+
+        const std::string msg = get_str_code() + "\n\n板一覧が " + location() + " に移転しました。更新しますか？";
+        SKELETON::MsgDiag mdiag( nullptr, msg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+        mdiag.set_default_response( Gtk::RESPONSE_YES );
+        if( mdiag.run() == Gtk::RESPONSE_YES ){
+            set_date_modified( std::string() );
+            CONFIG::set_url_bbsmenu( location() );
+            download_bbsmenu();
+        }
+        return;
+    }
+
     if( get_code() != HTTP_OK ){
 
         std::string msg = get_str_code() + "\n\n板一覧の読み込みに失敗したため板一覧は更新されませんでした。\n\nプロキシ設定や板一覧を取得するサーバのアドレスを確認して、ファイルメニューから板一覧の再読み込みをして下さい。\n板一覧取得サーバのアドレスはabout:configで確認出来ます。";
@@ -399,7 +444,7 @@ void Root::bbsmenu2xml( const std::string& menu )
     const bool wchar = false;
 
     // menu のノードツリーを取得( menu がHTMLなので第二引数は true )
-    XML::Document html( menu, true );
+    const XML::Document html( menu, true );
 
     // XML用のノードツリーにルートノードを追加
     m_xml_document.clear();
@@ -412,14 +457,21 @@ void Root::bbsmenu2xml( const std::string& menu )
     bool enabled = true;
 
     // 現在の仕様では HTML > BODY > font[size="2"] の子要素が対象
-    XML::DomList targets = html.getElementsByTagName( "font" )[0]->childNodes();
-    std::list< XML::Dom* >::iterator it = targets.begin();
-    while( it != targets.end() )
+    // 特定のサイト(2ch.sc、next2ch.net)のbbsmenu.htmlにはfontタグがないため別のタグを使う
+    std::list<XML::Dom*> targets = html.getElementsByTagName( "font" );
+    if( targets.empty() ) targets = html.getElementsByTagName( "small" );
+    if( targets.empty() ) targets = html.getElementsByTagName( "body" );
+    if( targets.empty() ) {
+        MISC::ERRMSG( "parse error for bbsmenu" );
+        return;
+    }
+    targets = targets.front()->childNodes();
+    for( const XML::Dom* child : targets )
     {
         // 要素b( カテゴリ名 )
-        if( (*it)->nodeName() == "b" )
+        if( child->nodeName() == "b" )
         {
-            const std::string category = (*it)->firstChild()->nodeValue();
+            const std::string category = child->firstChild()->nodeValue();
 
             // 追加しないカテゴリ
             if( category == "チャット"
@@ -427,7 +479,6 @@ void Root::bbsmenu2xml( const std::string& menu )
              || category == "他のサイト" )
             {
                 enabled = false;
-                ++it;
                 continue;
             }
             else enabled = true;
@@ -437,10 +488,10 @@ void Root::bbsmenu2xml( const std::string& menu )
             subdir->setAttribute( "name", category );
         }
         // 要素bに続く要素a( 板URL )
-        else if( subdir && enabled && (*it)->nodeName() == "a" )
+        else if( subdir && enabled && child->nodeName() == "a" )
         {
-            const std::string board_name = (*it)->firstChild()->nodeValue();
-            const std::string url = (*it)->getAttribute( "href" );
+            const std::string board_name = child->firstChild()->nodeValue();
+            const std::string url = child->getAttribute( "href" );
 
             // 板として扱うURLかどうかで要素名を変える
             std::string element_name;
@@ -456,8 +507,6 @@ void Root::bbsmenu2xml( const std::string& menu )
             board->setAttribute( "name", board_name );
             board->setAttribute( "url", url );
         }
-
-        ++it;
     }
 
     root->setAttribute( "date_modified", get_date_modified() );
@@ -477,18 +526,15 @@ void Root::analyze_board_xml()
     m_analyzing_board_xml = true;
     m_analyzed_path_board.clear();
 
-    XML::DomList boards = m_xml_document.getElementsByTagName( "board" );
+    const std::list<XML::Dom*> boards = m_xml_document.getElementsByTagName( "board" );
 
-    std::list< XML::Dom* >::iterator it = boards.begin();
-    while( it != boards.end() )
+    for( const XML::Dom* child : boards )
     {
-        const std::string name = (*it)->getAttribute( "name" );
-        const std::string url = (*it)->getAttribute( "url" );
+        const std::string name = child->getAttribute( "name" );
+        const std::string url = child->getAttribute( "url" );
 
         //板情報セット
         set_board( url, name );
-
-        ++it;
     }
 
     // 移転があった
@@ -508,7 +554,7 @@ void Root::analyze_board_xml()
         }
     }
 
-    XML::Dom* root = m_xml_document.get_root_element( std::string( ROOT_NODE_NAME ) );
+    const XML::Dom* root = m_xml_document.get_root_element( std::string( ROOT_NODE_NAME ) );
     if( root ) set_date_modified( root->getAttribute( "date_modified" ) );
 
     m_analyzing_board_xml = false;
@@ -582,7 +628,7 @@ int Root::get_board_type( const std::string& url, std::string& root, std::string
     // ローカルファイル
     else if( is_local( url ) ){
 
-        root = URL_BOARD_LOCAL;
+        root = "file://";
         path_board = "/local";
 
         type = TYPE_BOARD_LOCAL;
@@ -754,8 +800,8 @@ bool Root::move_board( const std::string& url_old, const std::string& url_new, c
     if( ! exec_move_board( board,
                            board->get_root(),
                            board->get_path_board(),
-                           root,
-                           path_board
+                           std::move( root ),
+                           std::move( path_board )
             ) ) return false;
 
     // キャッシュを移動した
@@ -779,13 +825,14 @@ bool Root::move_board( const std::string& url_old, const std::string& url_new, c
 //
 // 板移転処理実行
 //
+// 引数を参照渡し(const std::string&)するとDB更新で値が変わるため値渡しする
+//
 bool Root::exec_move_board( BoardBase* board,
-                       const std::string old_root,
-                       const std::string old_path_board,
-                       const std::string new_root,
-                       const std::string new_path_board
-    ){
-
+                            std::string old_root,
+                            std::string old_path_board,
+                            std::string new_root,
+                            std::string new_path_board )
+{
     if( ! board ) return false;
 
 #ifdef _SHOW_BOARD
@@ -849,7 +896,8 @@ bool Root::exec_move_board( BoardBase* board,
                   << "old_path_board = " << old_path_board << std::endl
                   << "new_path_board = " << new_path_board << std::endl;
 #endif
-        push_movetable( old_root, old_path_board, new_root, new_path_board );
+        push_movetable( std::move( old_root ), std::move( old_path_board ),
+                        std::move( new_root ), std::move( new_path_board ) );
 
         // この板に関連する表示中のviewのURLを更新
         CORE::core_set_command( "update_url", old_url, new_url );
@@ -862,11 +910,10 @@ bool Root::exec_move_board( BoardBase* board,
 //
 // 板移転テーブルを更新
 //
-void Root::push_movetable( const std::string old_root,
-                           const std::string old_path_board,
-                           const std::string new_root,
-                           const std::string new_path_board
-    )
+void Root::push_movetable( std::string old_root,
+                           std::string old_path_board,
+                           std::string new_root,
+                           std::string new_path_board )
 {
 #ifdef _DEBUG
     std::cout << "Root::push_movetable : " << old_root << old_path_board << " -> " << new_root << new_path_board << std::endl;
@@ -937,7 +984,7 @@ void Root::push_movetable( const std::string old_root,
             str += str_tmp;
 
             m_movetable.erase( it_move );
-            m_movetable.push_back( movetable );
+            m_movetable.push_back( std::move( movetable ) );
             it_move = m_movetable.begin();
             continue;
         }
@@ -948,11 +995,11 @@ void Root::push_movetable( const std::string old_root,
     if( ! str.empty() ) MISC::MSG( "\n" + str );
 
     MOVETABLE movetable;
-    movetable.old_root = old_root;
-    movetable.old_path_board = old_path_board;
-    movetable.new_root = new_root;
-    movetable.new_path_board = new_path_board;
-    m_movetable.push_back( movetable );
+    movetable.old_root = std::move( old_root );
+    movetable.old_path_board = std::move( old_path_board );
+    movetable.new_root = std::move( new_root );
+    movetable.new_path_board = std::move( new_path_board );
+    m_movetable.push_back( std::move( movetable ) );
 }
 
 
@@ -1263,10 +1310,10 @@ void Root::load_movetable()
 #endif 
    
     std::string file_move = CACHE::path_movetable();
-    std::string movetable;
-    if( CACHE::load_rawdata( file_move, movetable ) ){
+    std::string movetable_rawdata;
+    if( CACHE::load_rawdata( file_move, movetable_rawdata ) ){
 
-        std::list< std::string > list_table = MISC::get_lines( movetable );
+        std::list< std::string > list_table = MISC::get_lines( movetable_rawdata );
         std::list< std::string >::iterator it;
         for( it = list_table.begin(); it != list_table.end(); ++it ){
 
