@@ -23,7 +23,7 @@ namespace DBTREE
 
       public:
 
-        RuleLoader( const std::string& url_boardbase );
+        explicit RuleLoader( const std::string& url_boardbase );
         ~RuleLoader();
 
       protected:
@@ -37,6 +37,10 @@ namespace DBTREE
 
         // ロード後に呼び出される
         void parse_data() override;
+
+      private:
+
+        void receive_cookies() override;
     };
 }
 
