@@ -35,7 +35,7 @@ namespace DBTREE
 
       public:
 
-        SettingLoader( const std::string& url_boardbase );
+        explicit SettingLoader( const std::string& url_boardbase );
         ~SettingLoader();
 
         const std::string& default_noname() const { return m_default_noname; }
@@ -54,6 +54,10 @@ namespace DBTREE
 
         // ロード後に呼び出される
         void parse_data() override;
+
+      private:
+
+        void receive_cookies() override;
     };
 }
 
