@@ -206,11 +206,6 @@ std::string ENVIRONMENT::get_distname()
     std::string dist_name;
 
 #ifdef _WIN32
-    LONG rc;
-    DWORD dwSize;
-    HKEY hKey;
-    char *regVal;
-
     std::ostringstream vstr;
     vstr << "Windows";
 
@@ -218,6 +213,9 @@ std::string ENVIRONMENT::get_distname()
     osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEX);
     if (GetVersionEx((OSVERSIONINFO *)&osvi) != 0)
     {
+        LONG rc;
+        HKEY hKey;
+
         switch (osvi.dwPlatformId)
         {
         case VER_PLATFORM_WIN32_NT:
@@ -227,13 +225,15 @@ std::string ENVIRONMENT::get_distname()
                     0, KEY_READ | KEY_WOW64_64KEY, &hKey );
             if( rc == ERROR_SUCCESS )
             {
+                DWORD dwSize;
+
                 // read size of ProductName
                 rc = RegQueryValueEx( hKey, "ProductName",
                         nullptr, nullptr, nullptr, &dwSize );
                 if( rc == ERROR_SUCCESS && dwSize > 0 )
                 {
                     // get buffer
-                    regVal = (char *)malloc( dwSize );
+                    char* regVal = (char *)malloc( dwSize );
                     if( regVal != nullptr )
                     {
                         // read ProductName
@@ -255,7 +255,7 @@ std::string ENVIRONMENT::get_distname()
                 if( rc == ERROR_SUCCESS && dwSize > 0 )
                 {
                     // get buffer
-                    regVal = (char *)malloc( dwSize );
+                    char* regVal = (char *)malloc( dwSize );
                     if( regVal != nullptr )
                     {
                         // read CSDVersion
@@ -438,19 +438,20 @@ std::string ENVIRONMENT::get_distname()
     char *sysname = nullptr, *release = nullptr, *machine = nullptr;
 
     // システムコール uname() 準拠：SVr4, POSIX.1-2001.
-    struct utsname* uts;
-    uts = (struct utsname*)malloc( sizeof( struct utsname ) );
-    if( uname( uts ) != -1 )
+    struct utsname uts;
+    if( uname( &uts ) == 0 )
     {
-        sysname = uts->sysname;
-        release = uts->release;
-        machine = uts->machine;
+        sysname = uts.sysname;
+        release = uts.release;
+        machine = uts.machine;
     }
 
     // FreeBSD等やディストリ名が取得できなかった場合は"$ uname -rs"と同じ様式
     if( dist_name.empty() && sysname && release )
     {
-        dist_name = std::string( sysname ) + " " + std::string( release );
+        dist_name.append( sysname );
+        dist_name.push_back( ' ' );
+        dist_name.append( release );
     }
 
     // アーキテクチャがx86でない場合
@@ -465,9 +466,6 @@ std::string ENVIRONMENT::get_distname()
         if ( dist_name.find(arch, 0) == std::string::npos ) dist_name.append( " " + arch);
     }
 
-    free( uts );
-    uts = nullptr;
-
 #endif
 #endif // _WIN32
 
