@@ -39,6 +39,7 @@ FontColorPref::FontColorPref( Gtk::Window* parent, const std::string& url )
 
     // フォント設定をセット
     set_font_settings( "スレビュー", FONT_MAIN, "スレビューのフォント" );
+    set_font_settings( "メール欄とか", FONT_MAIL, "メール欄とかのフォント" );
     set_font_settings( "ポップアップ", FONT_POPUP, "ポップアップのフォント" );
     set_font_settings( "アスキーアート", FONT_AA, "AA(スレビュー)のフォント" );
     set_font_settings( "板一覧／お気に入り", FONT_BBS, "板一覧／お気に入りのフォント" );
@@ -400,6 +401,7 @@ void FontColorPref::set_color_settings( const int colorid, const std::string& na
     row[ m_columns_color.m_col_color ] = std::string();
     row[ m_columns_color.m_col_colorid ] = colorid;
     row[ m_columns_color.m_col_default ] = defaultval;
+    static_cast<void>( row ); // cppcheck: unreadVariable
 }
 
 
