@@ -90,7 +90,7 @@ ImageAdmin::~ImageAdmin()
     std::cout << "ImageAdmin::~ImageAdmin\n";
 #endif 
 
-    close_window();
+    ImageAdmin::close_window();
 }
 
 
@@ -551,7 +551,7 @@ void ImageAdmin::close_view( const std::string& url )
     SKELETON::View* view = get_view( url );
 
     if( ! icon && ! view ) return;
-    if( DBIMG::is_cached( url ) && icon->is_locked() ) return;
+    if( DBIMG::is_cached( url ) && icon && icon->is_locked() ) return;
 
     // 現在表示中のviewを閉じた場合は次か前の画像に切り替える
     if( view && view == get_current_view() ){
@@ -698,7 +698,7 @@ void ImageAdmin::close_right_views( const std::string& url )
 //
 // エラーになっている画像を閉じる
 //
-void ImageAdmin::close_error_views( const std::string mode )
+void ImageAdmin::close_error_views( const std::string& mode )
 {
 #ifdef _DEBUG
     std::cout << "ImageAdmin::close_error_views\n";
@@ -1095,11 +1095,6 @@ void ImageAdmin::save_all()
     std::cout << "ImageAdmin::save_all\n";
 #endif
 
-    int overwrite = Gtk::RESPONSE_NO;
-    bool use_name_in_cache = false;
-
-    std::list< std::string > list_urls = get_URLs();
-
     // ディレクトリ選択
     SKELETON::FileDiag diag( get_win(), "保存先選択", Gtk::FILE_CHOOSER_ACTION_SELECT_FOLDER );
 
@@ -1121,10 +1116,12 @@ void ImageAdmin::save_all()
 
             SESSION::set_dir_img_save( path_dir );
 
-            std::list< std::string >::iterator it = list_urls.begin();
-            for( ; it != list_urls.end(); ++it ){
+            int overwrite = Gtk::RESPONSE_NO;
+            bool use_name_in_cache = false;
+
+            const std::list<std::string> list_urls = get_URLs();
+            for( const std::string& url : list_urls ) {
 
-                std::string url = (*it);
                 if( ! DBIMG::is_cached( url ) || DBIMG::get_mosaic( url ) ) continue;
 
                 std::string path_from = DBIMG::get_cache_path( url );
