@@ -42,14 +42,10 @@ using namespace IMAGE;
 
 
 ImageViewBase::ImageViewBase( const std::string& url, const std::string& arg1, const std::string& arg2 )
-    : SKELETON::View( url ),
-      m_wait( false ),
-      m_loading( false ),
-      m_under_mouse( false ),
-      m_enable_menuslot( true )
+    : SKELETON::View( url )
+    , m_img{ DBIMG::get_img( get_url() ) } // 高速化のためデータベースに直接アクセス
+    , m_enable_menuslot( true )
 {
-    // 高速化のためデータベースに直接アクセス
-    m_img =  DBIMG::get_img( get_url() );
     assert( m_img );
 
     // マウスジェスチャ可能
@@ -95,6 +91,9 @@ void ImageViewBase::setup_common()
     // focus 可、モーションキャプチャ可
     m_event.set_can_focus( true );
     m_event.add_events( Gdk::POINTER_MOTION_MASK );
+#if GTKMM_CHECK_VERSION(3,3,18)
+    m_event.add_events( Gdk::SMOOTH_SCROLL_MASK );
+#endif
 
     m_event.signal_button_press_event().connect( sigc::mem_fun( *this, &ImageViewBase::slot_button_press ) );
     m_event.signal_button_release_event().connect( sigc::mem_fun( *this, &ImageViewBase::slot_button_release ) );
@@ -1190,7 +1189,6 @@ void ImageViewBase::activate_act_before_popupmenu( const std::string& url )
     m_enable_menuslot = false;
 
     Glib::RefPtr< Gtk::Action > act;
-    Glib::RefPtr< Gtk::ToggleAction > tact;
 
     bool current_protect = m_img->is_protected();
 
@@ -1198,7 +1196,7 @@ void ImageViewBase::activate_act_before_popupmenu( const std::string& url )
     act = action_group()->get_action( "LockTab" );
     if( act ){
 
-        Glib::RefPtr< Gtk::ToggleAction > tact = Glib::RefPtr< Gtk::ToggleAction >::cast_dynamic( act ); 
+        auto tact = Glib::RefPtr< Gtk::ToggleAction >::cast_dynamic( act );
         if( is_locked() ) tact->set_active( true );
         else tact->set_active( false );
     }
@@ -1265,7 +1263,7 @@ void ImageViewBase::activate_act_before_popupmenu( const std::string& url )
 
             act->set_sensitive( true );
 
-            tact = Glib::RefPtr< Gtk::ToggleAction >::cast_dynamic( act ); 
+            auto tact = Glib::RefPtr< Gtk::ToggleAction >::cast_dynamic( act );
             if( tact ){
                 if( current_protect ) tact->set_active( true );
                 else tact->set_active( false );
