@@ -16,12 +16,8 @@ using namespace JDLIB;
 /* constructions ******************************************/
 
 ImgLoader::ImgLoader( const std::string& file )
-    : m_file( file ),
-      m_width( 0 ),
-      m_height( 0 ),
-      m_stop( false ),
-      m_y( 0 ),
-      m_loadedlevel( LOADLEVEL_INIT )
+    : m_file( file )
+    , m_loadedlevel( LOADLEVEL_INIT )
 {
 #ifdef _DEBUG
     std::cout << "ImgLoader::ImgLoader file = " << m_file << std::endl;
@@ -126,9 +122,6 @@ bool ImgLoader::load_imgfile( const int loadlevel )
 
     bool ret = true;
     FILE* f = nullptr;
-    const size_t bufsize = 8192;
-    size_t readsize = 0;
-    guint8 data[ bufsize ];
 
     f = fopen( to_locale_cstr( m_file ), "rb" );
     if( ! f ){
@@ -142,9 +135,12 @@ bool ImgLoader::load_imgfile( const int loadlevel )
         m_loader->signal_size_prepared().connect( sigc::mem_fun( *this, &ImgLoader::slot_size_prepared ) );
         m_loader->signal_area_updated().connect( sigc::mem_fun( *this, &ImgLoader::slot_area_updated ) );
 
+        constexpr std::size_t bufsize = 8192;
+        guint8 data[ bufsize ];
+
         while( ! m_stop ){
 
-            readsize = fread( data, 1, bufsize, f );
+            const std::size_t readsize = fread( data, 1, bufsize, f );
             if( readsize ) m_loader->write( data, readsize );
 
 #ifdef _DEBUG
@@ -254,17 +250,14 @@ ImgProvider& ImgProvider::get_provider()
 Glib::RefPtr< ImgLoader > ImgProvider::get_loader( const std::string& file )
 {
     // ImgLoaderキャッシュをサーチ
-    for( std::list< Glib::RefPtr< ImgLoader > >::iterator it = m_cache.begin();
-            it != m_cache.end(); it++ ) {
-        if( (*it)->equals( file ) ) {
-            Glib::RefPtr< ImgLoader > ret = *it;
-            // LRU: キャッシュをlistの先頭に移動
-            if( it != m_cache.begin() ) {
-                m_cache.erase( it );
-                m_cache.push_front( ret );
-            }
-            return ret;
-        }
+    auto it = std::find_if( m_cache.begin(), m_cache.end(),
+                            [&file]( const Glib::RefPtr<ImgLoader>& loader ) { return loader->equals( file ); } );
+    if( it != m_cache.begin() && it != m_cache.end() ) {
+        Glib::RefPtr<ImgLoader> ret = *it;
+        // LRU: キャッシュをlistの先頭に移動
+        m_cache.erase( it );
+        m_cache.push_front( ret );
+        return ret;
     }
     return Glib::RefPtr< ImgLoader >(); //null
 }
