@@ -29,6 +29,8 @@
 
 #include "httpcode.h"
 
+#include <algorithm>
+#include <array>
 #include <cstring>
 #include <mutex>
 #include <sstream>
@@ -64,6 +66,18 @@ bool initialized_loader = false;
 #endif
 
 
+namespace {
+
+std::string get_error_message( int err_code )
+{
+    std::string result = " [Errno " + std::to_string( err_code ) + "] ";
+    result.append( std::strerror( err_code ) );
+    return result;
+}
+
+} // namespace
+
+
 //
 // トークンとスレッド起動待ちキュー
 //
@@ -367,7 +381,7 @@ void Loader::stop()
 // byte_readfrom ( != 0 ならその位置からレジューム)
 // agent
 // referer
-// cookie_for_write
+// cookie_for_request
 // host_proxy ( != empty ならproxy使用 )
 // port_proxy ( == 0 なら 8080 )
 // basicauth_proxy
@@ -422,7 +436,7 @@ bool Loader::run( SKELETON::Loadable* cb, const LOADERDATA& data_in )
     }
     
     m_data.host = m_data.url.substr( i, i2 - i );
-    i = i2; m_data.path = m_data.url.substr( i2 );
+    m_data.path = m_data.url.substr( i2 );
 
     // ポートセット
 
@@ -458,12 +472,14 @@ bool Loader::run( SKELETON::Loadable* cb, const LOADERDATA& data_in )
     }
 
     // ssl使用指定
-    // HACK: don't use SSL to access 2ch via a scraping proxy
+    // HACK: httpsから始まるURLで プロキシを使わない or 2ch系サイトでない 場合はhttpsで送信する
+    constexpr std::array<const char*, 3> domains{ ".5ch.net", ".2ch.net", ".bbspink.com" };
+    const std::string& hostname = m_data.host;
+    const auto has_domain = [&hostname]( const char* d ) { return hostname.find( d ) != std::string::npos; };
+
     if( data_in.use_ssl
         || ( m_data.protocol.find( "https://" ) != std::string::npos
-             && m_data.host.find( ".2ch.net" ) == std::string::npos
-             && m_data.host.find( ".5ch.net" ) == std::string::npos
-             && m_data.host.find( ".bbspink.com" ) == std::string::npos
+             && ( data_in.host_proxy.empty() || std::none_of( domains.cbegin(), domains.cend(), has_domain ) )
            )
       ){
         m_data.use_ssl = true;
@@ -492,7 +508,7 @@ bool Loader::run( SKELETON::Loadable* cb, const LOADERDATA& data_in )
     m_data.contenttype = data_in.contenttype;
     m_data.agent = data_in.agent;
     m_data.referer = data_in.referer;
-    m_data.cookie_for_write = data_in.cookie_for_write;
+    m_data.cookie_for_request = data_in.cookie_for_request;
     m_data.timeout = MAX( TIMEOUT_MIN, data_in.timeout );
     m_data.ex_field = data_in.ex_field;
     m_data.basicauth = data_in.basicauth;
@@ -508,7 +524,7 @@ bool Loader::run( SKELETON::Loadable* cb, const LOADERDATA& data_in )
     std::cout << "contenttype: " << m_data.contenttype << std::endl;
     std::cout << "agent: " << m_data.agent << std::endl;
     std::cout << "referer: " << m_data.referer << std::endl;
-    std::cout << "cookie: " << m_data.cookie_for_write << std::endl;
+    std::cout << "cookie: " << m_data.cookie_for_request << std::endl;
     std::cout << "proxy: " << m_data.host_proxy << std::endl;
     std::cout << "port of proxy: " << m_data.port_proxy << std::endl;
     std::cout << "proxy basicauth : " << m_data.basicauth_proxy << std::endl;
@@ -600,6 +616,7 @@ bool Loader::send_connect( const int soc, std::string& errmsg )
 
             m_data.code = HTTP_ERR;
             errmsg = "send failed : " + m_data.url;
+            errmsg.append( get_error_message( errno ) );
             return false;
         }
 
@@ -622,6 +639,7 @@ bool Loader::send_connect( const int soc, std::string& errmsg )
         if( tmpsize < 0 && errno != EINTR ){
             m_data.code = HTTP_ERR;
             errmsg = "CONNECT: recv() failed";
+            errmsg.append( get_error_message( errno ) );
             return false;
         }
 
@@ -725,6 +743,7 @@ void Loader::run_main()
             m_data.code = HTTP_ERR;
             if( ! use_proxy ) errmsg = "connect failed : " + m_data.host;
             else errmsg = "connect failed : " + m_data.host_proxy;
+            errmsg.append( get_error_message( errno ) );
             goto EXIT_LOADING;
         }
     }
@@ -821,6 +840,7 @@ void Loader::run_main()
 
                 m_data.code = HTTP_ERR;
                 errmsg = "send failed : " + m_data.url;
+                errmsg.append( get_error_message( errno ) );
                 goto EXIT_LOADING;
             }
 
@@ -887,6 +907,7 @@ void Loader::run_main()
                 if( tmpsize < 0 && errno != EINTR ){
                     m_data.code = HTTP_ERR;         
                     errmsg = "recv() failed";
+                    errmsg.append( get_error_message( errno ) );
                     goto EXIT_LOADING;
                 }
 
@@ -914,14 +935,14 @@ void Loader::run_main()
                 // ヘッダ取得
                 if( receiving_header ){
 
-                    const int ret = receive_header( m_buf, read_size );
-                    if( ret == HTTP_ERR ){
+                    const int http_code = receive_header( m_buf, read_size );
+                    if( http_code == HTTP_ERR ){
 
                         m_data.code = HTTP_ERR;
                         errmsg = "invalid header : " + m_data.url;
                         goto EXIT_LOADING;
                     }
-                    else if( ret == HTTP_OK ) receiving_header = false;
+                    else if( http_code == HTTP_OK ) receiving_header = false;
                 }
 
                 if( m_data.length && m_data.length <= m_data.length_current + read_size ) break;
@@ -1077,15 +1098,13 @@ struct addrinfo* Loader::get_addrinfo( const std::string& hostname, const int po
 
     int ret;
     struct addrinfo hints, *res;
-    const int poststrlng = 256;
-    char port_str[ poststrlng ];
     memset( &hints, 0, sizeof( addrinfo ) );
     if( m_data.use_ipv6 ) hints.ai_family = AF_UNSPEC;
     else hints.ai_family = AF_INET;
     hints.ai_socktype = SOCK_STREAM;
 
-    snprintf( port_str, poststrlng, "%d", port );
-    ret = getaddrinfo( hostname.c_str(), port_str, &hints, &res );
+    const std::string port_str = std::to_string( port );
+    ret = getaddrinfo( hostname.c_str(), port_str.c_str(), &hints, &res );
     if( ret ) {
         MISC::ERRMSG( m_data.str_code );
         return nullptr;
@@ -1133,7 +1152,7 @@ std::string Loader::create_msg_send()
     // proxy basic認証
     if( use_proxy && ! m_data.basicauth_proxy.empty() ) msg << "Proxy-Authorization: Basic " << MISC::base64( m_data.basicauth_proxy ) << "\r\n";
 
-    if( ! m_data.cookie_for_write.empty() ) msg << "Cookie: " << m_data.cookie_for_write << "\r\n";
+    if( ! m_data.cookie_for_request.empty() ) msg << "Cookie: " << m_data.cookie_for_request << "\r\n";
 
     if( ! m_data.modified.empty() ) msg << "If-Modified-Since: " << m_data.modified << "\r\n";
 
@@ -1313,11 +1332,10 @@ bool Loader::analyze_header()
 //
 std::string Loader::analyze_header_option( const std::string& option )
 {
-    size_t i = 0, i2 = 0;
-    i = m_data.str_header.find( option, 0 );    
+    const std::size_t i = m_data.str_header.find( option, 0 );
     if( i != std::string::npos ){
-        const size_t option_length = option.length();
-        i2 = m_data.str_header.find( "\r\n", i );
+        const std::size_t option_length = option.length();
+        std::size_t i2 = m_data.str_header.find( "\r\n", i );
         if( i2 == std::string::npos ) i2 = m_data.str_header.find( "\n", i );
         if( i2 != std::string::npos ) return m_data.str_header.substr( i + option_length, i2 - ( i + option_length ) );
     }
@@ -1333,13 +1351,13 @@ std::string Loader::analyze_header_option( const std::string& option )
 std::list< std::string > Loader::analyze_header_option_list( const std::string& option )
 {
     std::list< std::string > str_list;
-    
-    size_t i = 0, i2 = 0;
-    const size_t option_length = option.length();
 
+    const std::size_t option_length = option.length();
+
+    std::size_t i2 = 0;
     for(;;){
 
-        i = m_data.str_header.find( option, i2 );    
+        const std::size_t i = m_data.str_header.find( option, i2 );
         if( i == std::string::npos ) break;
 
         i2 = m_data.str_header.find( "\r\n", i );
@@ -1483,10 +1501,6 @@ bool Loader::init_unzip()
 
     m_use_zlib = true;
         
-#ifdef USE_OLDZLIB
-    m_check_gzheader = true;
-#endif
-
     // zlib 初期化
     m_zstream.zalloc = Z_NULL;
     m_zstream.zfree = Z_NULL;
@@ -1494,19 +1508,8 @@ bool Loader::init_unzip()
     m_zstream.next_in = Z_NULL;
     m_zstream.avail_in = 0;
 
-#ifdef USE_OLDZLIB
-#ifdef _DEBUG
-    std::cout << "use old zlib\n";
-#endif
-    if ( inflateInit2( &m_zstream, -MAX_WBITS ) != Z_OK )
-#else
-#ifdef _DEBUG
-    std::cout << "use zlib12\n";
-#endif
     if ( inflateInit2( &m_zstream, 15 + 32 ) != Z_OK ) // デフォルトの15に+32する( windowBits = 47 )と自動でヘッダ認識
-#endif
-    {  
-
+    {
         MISC::ERRMSG( "inflateInit2 failed." );
         return false;
     }
@@ -1521,112 +1524,11 @@ bool Loader::init_unzip()
 
 
 
-#ifdef USE_OLDZLIB
-//
-// gzip のヘッダチェック
-//
-// 戻り値 : ヘッダのサイズ(エラーなら-1)
-//
-// TODO: size がヘッダサイズよりも小さいと必ず失敗する
-//
-int Loader::check_gzheader( char* buf, size_t& size )
-{
-#ifdef _DEBUG
-    std::cout << "Loader::check_gzheader\n";
-#endif    
-
-    m_check_gzheader = false;
-
-    unsigned int pos = 0;
-
-    if( ( ( unsigned char* )buf )[ pos++ ] != 0x1f || ( ( unsigned char* )buf )[ pos++ ] != 0x8b ) return -1;
-
-    // CM(1byte)
-    if( buf[ pos++ ] != 0x08 ) return false;
-
-    // FLG(1byte)
-    unsigned char flag =( ( unsigned char* )buf )[ pos++ ];
-#ifdef _DEBUG
-    std::cout << "flag = " << std::hex << ( unsigned int )flag << std::dec << std::endl;
-#endif
-    if( flag & 0xe0 ) return -1;
-
-    // MTIME(4byte), XFL(1byte), OS(1byte)を飛ばす
-    pos += 6;
-
-    // XLEN(2byte) + 拡張フィールド
-    if( flag & 4 ){
-        unsigned short lngext;
-        memcpy( &lngext, buf + pos, sizeof( unsigned short ) );
-#ifdef _DEBUG
-        std::cout << "FEXTRA lng = " << lngext << std::endl;
-#endif
-        pos += sizeof( unsigned short ) + lngext;
-    }
-
-    // NAME
-    if( flag & 8 ){
-        int i = 0;
-        char tmp_str[ 256 ];
-        while( pos < size && i < 256  && buf[ pos ] != '\0' ) tmp_str[ i++ ] = buf[ pos++ ];
-        tmp_str[ i ] = buf[ pos++ ];
-        if( tmp_str[ i ] != '\0' ) return -1;
-#ifdef _DEBUG
-        std::cout << "NAME = " << tmp_str << std::endl;
-#endif
-    }
-
-    // COMMENT
-    if( flag & 16 ){
-        int i = 0;
-        char tmp_str[ 256 ];
-        while( pos < size && i < 256  && buf[ pos ] != '\0' ) tmp_str[ i++ ] = buf[ pos++ ];
-        tmp_str[ i ] = buf[ pos++ ];
-        if( tmp_str[ i ] != '\0' ) return -1;
-#ifdef _DEBUG
-        std::cout << "COMMENT = " << tmp_str << std::endl;
-#endif
-    }
-
-    // CRC16
-    if(flag & 2 ){
-        pos += 2;
-#ifdef _DEBUG
-        std::cout << "CRC16\n";
-#endif
-    }
-
-    if( pos >= size ) return -1;
-
-#ifdef _DEBUG
-    std::cout << "header size = " << pos << std::endl;
-#endif
-
-    return pos;
-}
-#endif
-
-
-
 //
 // unzipしてコールバック呼び出し
 //
-bool Loader::unzip( char* buf, size_t& read_size )
+bool Loader::unzip( char* buf, std::size_t read_size )
 {
-#ifdef USE_OLDZLIB
-    // gzip のヘッダを飛ばす
-    if( m_check_gzheader ){
-        int headsize = check_gzheader( buf, read_size );
-        if( headsize < 0 ){
-
-            MISC::ERRMSG( "invalid gzip header : " + m_data.url );
-            return false;
-        }
-        buf += headsize;
-        read_size -= headsize;
-    }
-#endif    
-
     // zlibの入力バッファに値セット
     if( m_zstream.avail_in + read_size > m_lng_buf_zlib_in ){ // オーバーフローのチェック
 
@@ -1643,7 +1545,6 @@ bool Loader::unzip( char* buf, size_t& read_size )
         // 出力バッファセット
         m_zstream.next_out = m_buf_zlib_out;
         m_zstream.avail_out = m_lng_buf_zlib_out;
-        byte_out = 0;
 
         // 解凍
         int ret = inflate( &m_zstream, Z_NO_FLUSH );
@@ -1659,13 +1560,6 @@ bool Loader::unzip( char* buf, size_t& read_size )
             
             // コールバック呼び出し
             if( byte_out && m_loadable ) m_loadable->receive( ( char* )m_buf_zlib_out, byte_out );
-
-#ifdef USE_OLDZLIB
-            if( ret == Z_STREAM_END ){
-                m_zstream.avail_in = 0; // CRC32(4byte)とISIZE(4byte)の分を引く
-                return true;
-            }
-#endif            
         }
         else return true;
                 
