@@ -24,14 +24,6 @@
 #include <netdb.h>
 #endif
 
-// zlibが1.2よりバージョンが低いか判定する
-#ifndef ZLIB_VERNUM
-#define ZLIB_VERNUM 0x1000
-#endif
-#if ZLIB_VERNUM < 0x1200
-#define USE_OLDZLIB
-#endif
-
 
 namespace SKELETON
 {
@@ -74,14 +66,11 @@ namespace JDLIB
         // zlib 用変数
         bool m_use_zlib;
         z_stream m_zstream;
-#ifdef USE_OLDZLIB
-        bool m_check_gzheader;
-#endif
-        
+
     public:
 
         // low_priority = true の時はスレッド起動待ち状態になった時に、起動順のプライオリティを下げる
-        Loader( const bool low_priority );
+        explicit Loader( const bool low_priority );
         ~Loader();
 
         bool is_loading() const { return m_loading; }
@@ -120,10 +109,7 @@ namespace JDLIB
 
         // unzip 用
         bool init_unzip();
-        bool unzip( char* buf, size_t& read_size );
-#ifdef USE_OLDZLIB
-        int check_gzheader( char* buf, size_t& size );
-#endif        
+        bool unzip( char* buf, std::size_t read_size );
     };
 
     // ローダの起動待ちキューにあるスレッドを実行しない
