@@ -24,9 +24,9 @@
 std::list< std::string > MISC::get_lines( const std::string& str ){
         
     std::list< std::string > lines;
-    size_t i = 0, i2 = 0, r = 0;
+    size_t i = 0, i2 = 0;
     while ( ( i2 = str.find( '\n', i ) ) != std::string::npos ){
-        r = 0;
+        std::size_t r = 0;
         if( (i2 >= 1) && (str[ i2 - 1 ] == '\r') ) r = 1;
         if( i2 - i > 0 ){
             lines.push_back( str.substr( i, i2 - i - r ) );
@@ -51,20 +51,19 @@ std::list< std::string > MISC::get_elisp_lists( const std::string& str )
 #endif 
    
     std::list< std::string > lists;
-    size_t pos = 0, length = 0;
     std::string str2 = remove_space( str );
     const char* data = str2.c_str();
     if( data[ 0 ] != '(' ) return lists;
 
-    pos = 1;
+    std::size_t pos = 1;
 
     while( data[ pos ] != '\0' ){
 
         // 空白削除
-        while( data[ pos ] == ' ' && data[ pos ] != '\0' ) ++pos;
+        while( data[ pos ] == ' ' ) ++pos;
         if( data[ pos ] == '\0' ) break;
 
-        length = 1;
+        std::size_t length = 1;
 
         // (が現れた
         if( data[ pos ] == '(' ){
@@ -113,11 +112,10 @@ std::list< std::string > MISC::split_line( const std::string& str )
 {
     constexpr const char* str_space = u8"\u3000"; // "\xE3\x80\x80" 全角スペース
     constexpr size_t lng_space = 3;
-    bool dquote;
 
     std::list< std::string > list_str;
 
-    size_t i = 0, i2 = 0, lng = str.length();
+    size_t i = 0, lng = str.length();
     for(;;){
 
         // 空白を取る
@@ -135,14 +133,14 @@ std::list< std::string > MISC::split_line( const std::string& str )
         }
 
         // " から始まる ( \"は除く )
-        dquote = false;
-        if( str[ i ] == '\"' && (i < 1 || str[ i -1 ] != '\\') ){
+        bool dquote = false;
+        if( (i < 1 || str[ i -1 ] != '\\') && str[ i ] == '\"' ){
             dquote = true;
             ++i;
         }
 
         // 空白か " を探す
-        i2 = i;
+        std::size_t i2 = i;
         size_t lng_tmp = 1;
         while( i2 < lng ){
 
@@ -304,7 +302,7 @@ std::string MISC::remove_space( const std::string& str )
 
     // 前
     size_t i = 0;
-    while( 1 ){
+    while( i < lng ){
 
         // 半角
         if( str[ i ] == ' ' ) ++i;
@@ -315,6 +313,7 @@ std::string MISC::remove_space( const std::string& str )
                  str[ i +2 ] == str_space[ 2 ] ) i += lng_space;
         else break;
     }
+    if (i >= lng) return "";
 
     // 後
     size_t i2 = lng -1;
@@ -930,49 +929,46 @@ int MISC::is_url_scheme_impl( const char* str_in, int* length )
     int len = 0;
 
     // http https
-    if( *str_in == 'h' && *( str_in + 1 ) == 't'
-        && *( str_in + 2 ) == 't' && *( str_in + 3 ) == 'p' )
+    if( MISC::starts_with( str_in, "http" ) )
     {
         scheme = SCHEME_HTTP;
         len = 4;
         if( *( str_in + len ) == 's' ) ++len;
     }
     // ftp
-    else if( *str_in == 'f' && *( str_in + 1 ) == 't' && *( str_in + 2 ) == 'p' )
+    else if( MISC::starts_with( str_in, "ftp" ) )
     {
         scheme = SCHEME_FTP;
         len = 3;
     }
     // ttp ttps
-    else if( *str_in == 't' && *( str_in + 1 ) == 't' && *( str_in + 2 ) == 'p' )
+    else if( MISC::starts_with( str_in, "ttp" ) )
     {
         scheme = SCHEME_TTP;
         len = 3;
         if( *( str_in + len ) == 's' ) ++len;
     }
     // tp tps
-    else if( *str_in == 't' && *( str_in + 1 ) == 'p' )
+    else if( MISC::starts_with( str_in, "tp" ) )
     {
         scheme = SCHEME_TP;
         len = 2;
         if( *( str_in + len ) == 's' ) ++len;
     }
     // sssp
-    else if( *str_in == 's' && *( str_in + 1 ) == 's' && *( str_in + 2 ) == 's' && *( str_in + 3 ) == 'p' ){
-        if( *( str_in + 7 ) == 'i' && *( str_in + 8 ) == 'm' && *( str_in + 9 ) == 'g' && *( str_in + 10 ) == '.'
-             && *( str_in + 11 ) == '2' && *( str_in + 12 ) == 'c' && *( str_in + 13 ) == 'h'){
+    else if( MISC::starts_with( str_in, "sssp" ) ) {
+        if( MISC::starts_with( str_in + 7, "img.5ch" ) || MISC::starts_with( str_in + 7, "img.2ch" ) ) {
             scheme = SCHEME_SSSP;
         }
         else{
-            // XXX img.2ch以外のアドレスはHTTPスキームにする
+            // XXX img.[25]ch以外のアドレスはHTTPスキームにする
             scheme = SCHEME_HTTP;
         }
         len = 4;
     }
 
     // 各スキーム後に続く共通の"://"
-    if( *( str_in + len ) == ':' && *( str_in + len + 1 ) == '/'
-        && *( str_in + len + 2 ) == '/' )
+    if( MISC::starts_with( str_in + len, "://" ) )
     {
         len += 3;
         if( length ) *length = len;
@@ -1653,7 +1649,7 @@ std::string MISC::get_hostname( const std::string& path, bool protocol )
 
     size_t i = path.find( "/", lng ); 
 
-    if( i == std::string::npos ) path.substr( pos );
+    if( i == std::string::npos ) return path.substr( pos );
 
     return path.substr( pos, i - pos );
 }
@@ -1701,7 +1697,7 @@ std::string MISC::getenv_limited( const char *name, const size_t size )
     strncpy( env.data(), getenv( name ), size );
 
 #ifdef _WIN32
-    return recover_path( Glib::locale_to_utf8( std::string( env.data() ) );
+    return recover_path( Glib::locale_to_utf8( std::string( env.data() ) ) );
 #else
     return env.data();
 #endif
@@ -1725,7 +1721,7 @@ std::string MISC::recover_path( const std::string& str )
 #endif
 }
 
-std::vector< std::string > MISC::recover_path( std::vector< std::string >&& list_str )
+std::vector< std::string > MISC::recover_path( std::vector< std::string > list_str )
 {
 #ifdef _WIN32
     std::vector< std::string > list_ret;
@@ -1794,14 +1790,16 @@ bool MISC::has_widechar( const char* str )
 //
 void MISC::asc( const char* str1, std::string& str2, std::vector< int >& table_pos )
 {
-    for( int pos = 0; str1[ pos ] != '\0'; ) {
+    int pos = 0;
+    while( str1[ pos ] != '\0' ) {
         assert( pos >= 0 );
         assert( table_pos.max_size() > table_pos.size() );
         const auto in1 = static_cast< unsigned char >( str1[ pos ] );
 
         if( in1 == 0xef ) {
             const auto in2 = static_cast< unsigned char >( str1[ pos + 1 ] );
-            const auto in3 = static_cast< unsigned char >( str1[ pos + 2 ] );
+            unsigned char in3 = 0;
+            if ( in2 ) in3 = static_cast< unsigned char >( str1[ pos + 2 ] );
 
             if( in2 == 0xbc ){
                 //  全角数字 (U+FF10 - U+FF19)
@@ -1837,8 +1835,10 @@ void MISC::asc( const char* str1, std::string& str2, std::vector< int >& table_p
                 size_t i = 0;
 
                 // 濁点、半濁点
-                const auto in4 = static_cast< unsigned char >( str1[ pos + 3 ] );
-                const auto in5 = static_cast< unsigned char >( str1[ pos + 4 ] );
+                unsigned char in4 = 0;
+                unsigned char in5 = 0;
+                if ( in3 ) in4 = static_cast< unsigned char >( str1[ pos + 3 ] );
+                if ( in4 ) in5 = static_cast< unsigned char >( str1[ pos + 4 ] );
                 if( in4 == 0xef && in5 == 0xbe ){
                     const auto in6 = static_cast< unsigned char >( str1[ pos + 5 ] );
 
@@ -1877,4 +1877,23 @@ void MISC::asc( const char* str1, std::string& str2, std::vector< int >& table_p
         table_pos.push_back( pos );
         ++pos;
     }
+    // 文字列の終端（ヌル文字）の位置を追加する。
+    // ヌル文字の位置がないと検索対象の末尾にマッチングしたとき範囲外アクセスが発生する。
+    table_pos.push_back( pos );
+}
+
+
+//
+// selfの先頭部分がstartsと等しいか（ヌル終端文字列バージョン）
+// Unicode正規化は行わなずバイト列として比較する
+//
+// self : 対象の文字列
+// starts : 先頭部分
+//
+bool MISC::starts_with( const char* self, const char* starts )
+{
+    for( std::size_t i = 0; starts[i] != '\0'; ++i ) {
+        if( self[i] == '\0' || self[i] != starts[i] ) return false;
+    }
+    return true;
 }
