@@ -27,11 +27,10 @@ std::map< UINT_PTR, Timeout* > Timeout::s_timeouts;
 // private
 Timeout::Timeout( const sigc::slot< bool > slot_timeout )
     : m_slot_timeout( slot_timeout )
-{
 #ifdef _WIN32
-    m_identifer = 0;
-    m_context = Glib::MainContext::get_default();
+    , m_context{ Glib::MainContext::get_default() }
 #endif
+{
 }
 
 Timeout::~Timeout()
@@ -49,7 +48,7 @@ Timeout::~Timeout()
 }
 
 // static
-Timeout* Timeout::connect( const sigc::slot< bool > slot_timeout, unsigned int interval )
+std::unique_ptr<Timeout> Timeout::connect( const sigc::slot< bool > slot_timeout, unsigned int interval )
 {
     Timeout* timeout = new Timeout( slot_timeout );
 #ifdef _WIN32
@@ -68,7 +67,7 @@ Timeout* Timeout::connect( const sigc::slot< bool > slot_timeout, unsigned int i
 #else
     timeout->m_connection = Glib::signal_timeout().connect( slot_timeout, interval );
 #endif
-    return timeout;
+    return std::unique_ptr<Timeout>( timeout );
 }
 
 #ifdef _WIN32
