@@ -10,6 +10,9 @@
 #include <mutex>
 #endif
 
+#include <memory>
+
+
 namespace JDLIB
 {
     class Timeout
@@ -17,8 +20,8 @@ namespace JDLIB
         sigc::slot< bool > m_slot_timeout;
 #ifdef _WIN32
         Glib::RefPtr<Glib::MainContext> m_context;
-        UINT_PTR m_identifer;
-        
+        UINT_PTR m_identifer{};
+
         static std::mutex s_lock;
         static std::map< UINT_PTR, Timeout* > s_timeouts;
 #else
@@ -28,10 +31,10 @@ namespace JDLIB
     public:
         ~Timeout();
         
-        static Timeout* connect( const sigc::slot< bool > slot_timeout, unsigned int interval );
+        static std::unique_ptr<Timeout> connect( const sigc::slot< bool > slot_timeout, unsigned int interval );
 
     private:
-        Timeout( const sigc::slot< bool > slot_timeout );
+        explicit Timeout( const sigc::slot< bool > slot_timeout );
         
 #ifdef _WIN32
         void slot_timeout_callback();
