@@ -29,10 +29,6 @@
 #include <iostream>
 #include <getopt.h>
 
-#ifdef USE_GNOMEUI
-#include <gnome.h>
-#endif
-
 #ifdef USE_XSMP
 #include <X11/ICE/ICElib.h>
 #include <X11/SM/SMlib.h>
@@ -137,29 +133,6 @@ void sig_handler( int sig )
 
 
 
-// GNOMEUI によるセッション管理
-#ifdef USE_GNOMEUI
-
-// gnomeセッションマネージャから "save_yourself" シグナルを受け取った
-static int save_yourself_gnome( GnomeClient *client,
-                          int phase,
-                          GnomeSaveStyle save_style,
-                          int shutdown,
-                          GnomeInteractStyle interact_style,
-                          int fast,
-                          gpointer client_data
-    )
-{
-
-    if( Win_Main ) Win_Main->save_session();
-
-    return TRUE;
-}
-
-#endif
-
-
-
 // XSMPによるセッション管理
 #ifdef USE_XSMP
 
@@ -221,7 +194,7 @@ void ice_watch_proc( IceConn ice_connect,
                      Bool opening,
                      IcePointer *watch_data )
 {
-    XSMPDATA *xsmpdata = ( XSMPDATA* ) client_data;
+    XSMPDATA *xsmpdata = reinterpret_cast<XSMPDATA*>( client_data );
     xsmpdata->ice_connect = ice_connect;
 
     if( xsmpdata->id_process_message ){
@@ -487,23 +460,6 @@ int main( int argc, char **argv )
     }
 #endif
 
-#if !GLIB_CHECK_VERSION(2,45,5)
-#ifdef _DEBUG_MEM_PROFILE
-    g_mem_set_vtable( glib_mem_profiler_table );
-    atexit( g_mem_profile );
-#else
-    GMemVTable vtable;
-    vtable = *glib_mem_profiler_table;
-    vtable.malloc = malloc;
-    vtable.realloc = realloc;
-    vtable.free = free;
-    vtable.calloc = calloc;
-    vtable.try_malloc = malloc;
-    vtable.try_realloc = realloc;
-    g_mem_set_vtable( &vtable );
-#endif
-#endif
-
     Gtk::Main m( &argc, &argv );
 
     // XSMPによるセッション管理
@@ -518,20 +474,6 @@ int main( int argc, char **argv )
     xsmp_session_init( &xsmpdata );    
 #endif
 
-    // GNOMEUIによるセッション管理
-#ifdef USE_GNOMEUI
-
-#ifdef _DEBUG
-    std::cout << "USE_GNOMEUI\n";
-#endif
-
-    // gnomeセッションマネージャとつないでログアウト時に"save_yourself"シグナルをもらう
-    gnome_init( "jdim", "1.0", argc, argv );
-    GnomeClient *client_gnome = gnome_master_client();
-    if( client_gnome ) gtk_signal_connect( GTK_OBJECT( client_gnome ), "save_yourself", GTK_SIGNAL_FUNC( save_yourself_gnome ), nullptr );
-    else MISC::ERRMSG( "failed to connect to gnome session manager" );
-#endif
-
     JDLIB::init_ssl();
 
     // 全体設定ロード
@@ -559,10 +501,10 @@ int main( int argc, char **argv )
     // メッセージをログファイルに出力
     if( logfile_mode && CACHE::mkdir_logroot() ){
         FILE *tmp; // warning 消し
-        const char *logfile = to_locale_cstr( CACHE::path_msglog() );
-        tmp = freopen( logfile, "ab", stdout );
+        const std::string logfile = Glib::locale_from_utf8( CACHE::path_msglog() );
+        tmp = freopen( logfile.c_str(), "ab", stdout );
         setbuf( tmp, nullptr );
-        tmp = freopen( logfile, "ab", stderr );
+        tmp = freopen( logfile.c_str(), "ab", stderr );
         setbuf( tmp, nullptr );
     }
 
