@@ -11,7 +11,6 @@
 #include "session.h"
 #include "login2ch.h"
 #include "loginbe.h"
-#include "loginp2.h"
 #include "winmain.h"
 #include "fontid.h"
 #include "colorid.h"
@@ -131,28 +130,6 @@ void Core::slot_toggle_loginbe()
 }
 
 
-//
-// p2にログイン
-//
-void Core::slot_toggle_loginp2()
-{
-    if( ! m_enable_menuslot ) return;
-
-#ifdef _DEBUG
-    std::cout << "Core::slot_toggle_loginp2\n";
-#endif
-
-    // ログイン中ならログアウト
-    if( CORE::get_loginp2()->login_now() ){
-        CORE::get_loginp2()->logout();
-        set_maintitle();
-    }
-
-    // ログオフ中ならログイン開始
-    else CORE::get_loginp2()->start_login();
-}
-
-
 //
 // 板リスト再読込
 //
@@ -808,6 +785,25 @@ void Core::slot_changefont_main()
     }
 }
 
+//
+// メールのフォント変更
+//
+void Core::slot_changefont_mail()
+{
+    FontSelectionDialog diag;
+    diag.set_font_name( CONFIG::get_fontname( FONT_MAIL ) );
+    diag.set_title( "メール欄のフォント" );
+    diag.set_transient_for( *CORE::get_mainwindow() );
+    if( diag.run() == Gtk::RESPONSE_OK ){
+
+        CONFIG::set_fontname( FONT_MAIL, diag.get_font_name() );
+        ARTICLE::get_admin()->set_command( "init_font" );
+        ARTICLE::get_admin()->set_command( "relayout_all" );
+
+        CONFIG::set_fontname( FONT_MESSAGE, diag.get_font_name() );
+        MESSAGE::get_admin()->set_command( "relayout_all" );
+    }
+}
 
 //
 // ポップアップフォント変更
