@@ -128,14 +128,13 @@ void MessageAdmin::command_local( const COMMAND_ARGS& command )
     // かつ書き込みビューが空なら閉じる
     else if( command.command == "close_message" ){
 
-        SKELETON::View *view = get_current_view();
         if( view && view->set_command( "empty" ) && view->get_url().find( command.url ) != std::string::npos ){
             close_current_view();
         }
     }
 
     // ビューの wrap 切り替え
-    else if( "toggle_wrap" ){
+    else if( command.command == "toggle_wrap" ){
 
         if( view ) view->set_command( command.command );
     }
