@@ -20,6 +20,17 @@ namespace SKELETON
 
 namespace MESSAGE
 {
+    // 投稿の種類で異なるインターフェース部分を抽象クラスにしてStrategyパターンを使う
+    // 実行時にコンストラクタでインターフェースを選択する
+    struct PostStrategy
+    {
+        virtual ~PostStrategy() noexcept = default;
+        virtual std::string url_bbscgi( const std::string& url ) = 0; // 1回目の投稿先
+        virtual std::string url_subbbscgi( const std::string& url ) = 0; // 2回目の投稿先
+        virtual void analyze_keyword( const std::string& url, const std::string& html ) = 0; // キーワードを解析
+        virtual std::string get_keyword( const std::string& url ) = 0; // キーワードをゲット
+    };
+
     class Post : public SKELETON::Loadable
     {
         // ポスト終了シグナル
@@ -42,6 +53,8 @@ namespace MESSAGE
         // 書き込んでいますのダイアログ
         SKELETON::MsgDiag* m_writingdiag;
 
+        PostStrategy* m_post_strategy;
+
       public:
 
         Post( Gtk::Widget* parent, const std::string& url, const std::string& msg, bool new_article );
