@@ -10,7 +10,6 @@
 
 #include "login2ch.h"
 #include "loginbe.h"
-#include "loginp2.h"
 
 #include "jdlib/miscutil.h"
 
@@ -86,35 +85,6 @@ namespace CORE
     };
 
 
-    // p2ログイン用
-    class PasswdFramep2 : public Gtk::VBox
-    {
-        Gtk::Label m_label;
-
-      public:
-
-        SKELETON::LabelEntry entry_id;
-        SKELETON::LabelEntry entry_passwd;
-
-      PasswdFramep2()
-        : m_label( "2ch、BEへのログインはp2から行って下さい" ),
-        entry_id( true, "ユーザID(_I)： " ), entry_passwd( true, "パスワード(_P)： " )
-        {
-            set_border_width( BOXSPACING );
-
-            entry_id.set_border_width( BOXSPACING );
-            pack_start( entry_id );
-
-            entry_passwd.set_border_width( BOXSPACING );
-            entry_passwd.set_visibility( false );
-            pack_start( entry_passwd, Gtk::PACK_SHRINK );
-
-            pack_start( m_label );
-
-            set_border_width( BOXSPACING );
-        }
-    };
-
     class PasswdPref : public SKELETON::PrefDiag
     {
 
@@ -122,7 +92,6 @@ namespace CORE
 
         PasswdFrame2ch m_frame_2ch;
         PasswdFrameBe m_frame_be;
-        PasswdFramep2 m_frame_p2;
 
         // OK押した
         void slot_ok_clicked() override
@@ -134,10 +103,6 @@ namespace CORE
             // BE
             CORE::get_loginbe()->set_username( MISC::remove_space( m_frame_be.entry_id.get_text() ) );
             CORE::get_loginbe()->set_passwd( MISC::remove_space( m_frame_be.entry_passwd.get_text() ) );
-
-            // p2
-            CORE::get_loginp2()->set_username( MISC::remove_space( m_frame_p2.entry_id.get_text() ) );
-            CORE::get_loginp2()->set_passwd( MISC::remove_space( m_frame_p2.entry_passwd.get_text() ) );
         }
 
       public:
@@ -160,16 +125,8 @@ namespace CORE
             set_activate_entry( m_frame_be.entry_id );
             set_activate_entry( m_frame_be.entry_passwd );
 
-            // p2ログイン用
-            m_frame_p2.entry_id.set_text( CORE::get_loginp2()->get_username() );
-            m_frame_p2.entry_passwd.set_text( CORE::get_loginp2()->get_passwd() );
-
-            set_activate_entry( m_frame_p2.entry_id );
-            set_activate_entry( m_frame_p2.entry_passwd );
-
             m_notebook.append_page( m_frame_2ch, "2ch" );
             m_notebook.append_page( m_frame_be, "BE" );
-            m_notebook.append_page( m_frame_p2, "p2" );
             get_vbox()->pack_start( m_notebook );
 
             set_title( "パスワード設定" );
