@@ -54,7 +54,8 @@ namespace CORE
         PREFDIAG_NONE
     };
     
-    SKELETON::PrefDiag* PrefDiagFactory( Gtk::Window* parent, const int type, const std::string& url, const std::string command = std::string() );
+    SKELETON::PrefDiag* PrefDiagFactory( Gtk::Window* parent, const int type, const std::string& url,
+                                         const std::string& command = {} );
 }
 
 #endif
