@@ -66,13 +66,13 @@ int get_uptodate_type( const std::string& url, const int type_org )
     if( type == TYPE_BOARD || type == TYPE_BOARD_UPDATE ){
 
         if( DBTREE::board_status( url ) & STATUS_UPDATE ) type = TYPE_BOARD_UPDATE;
-        else if( type != TYPE_BOARD ) type = TYPE_BOARD;
+        else type = TYPE_BOARD;
     }
     else if( type == TYPE_THREAD || type == TYPE_THREAD_UPDATE || type == TYPE_THREAD_OLD ){
 
         if( DBTREE::article_status( url ) & STATUS_OLD ) type = TYPE_THREAD_OLD;
         else if( DBTREE::article_status( url ) & STATUS_UPDATE ) type = TYPE_THREAD_UPDATE;
-        else if( type != TYPE_THREAD ) type = TYPE_THREAD;
+        else type = TYPE_THREAD;
     }
 
     return type;
@@ -172,39 +172,14 @@ EditTreeView::EditTreeView( const std::string& url, const std::string& dndtarget
     : DragTreeView( url, dndtarget, use_usr_fontcolor, fontname, colorid_text, colorid_bg, colorid_bg_even ),
       m_url( url ),
       m_columns( columns )
-{
-    setup();
-}
+{}
 
 
 EditTreeView::EditTreeView( const std::string& url, const std::string& dndtarget, EditColumns& columns )
     : DragTreeView( url, dndtarget, false, "", 0, 0, 0 ),
       m_url( url ),
       m_columns( columns )
-{
-    setup();
-}
-
-
-void EditTreeView::setup()
-{
-#ifdef _DEBUG
-    std::cout << "EditTreeView::Setup url = " << m_url << std::endl;
-#endif
-
-    m_parent_win = nullptr;
-
-    m_updated = false;
-    m_dragging_on_tree = false;
-    m_editable = false;
-    m_undo_buffer = nullptr;
-    m_dnd_counter = 0;
-    m_row_dest = Gtk::TreeRow();
-
-    m_pre_adjust_upper = 0;
-    m_jump_path = Gtk::TreePath();
-}
-
+{}
 
 
 EditTreeView::~EditTreeView()
@@ -333,7 +308,7 @@ void EditTreeView::set_treestore( const Glib::RefPtr< Gtk::TreeStore >& treestor
 //
 // xml -> tree 展開して treestore をセットする
 //
-void EditTreeView::xml2tree( XML::Document& document, Glib::RefPtr< Gtk::TreeStore >& treestore, const std::string& root_name )
+void EditTreeView::xml2tree( const XML::Document& document, Glib::RefPtr< Gtk::TreeStore >& treestore, const std::string& root_name )
 {
 #ifdef _DEBUG
     std::cout << "EditTreeView::xml2tree ";
@@ -926,13 +901,14 @@ void EditTreeView::draw_underline( const Gtk::TreePath& path, const bool draw )
     if( ! row ) return;
 
     row[ m_columns.m_underline ] = draw;
+    static_cast<void>( row ); // cppcheck: unreadVariable
 }
 
 
 //
 // path は ディレクトリか
 //
-bool EditTreeView::is_dir( Gtk::TreeModel::iterator& it )
+bool EditTreeView::is_dir( const Gtk::TreeModel::iterator& it ) const
 {
     const Gtk::TreeRow row = ( *it );
     if( ! row ) return false;
@@ -1217,8 +1193,8 @@ void EditTreeView::delete_selected_rows( const bool force )
 
     // 削除する行を取得
     CORE::DATA_INFO_LIST list_info;
-    const bool dir = true;
-    get_info_in_selection( list_info, dir );
+    constexpr bool scan_in_dir = true;
+    get_info_in_selection( list_info, scan_in_dir );
 
     // カーソルを最後の行の次の行に移動するため、あらかじめ削除範囲の最後の行に移動しておく
     const Gtk::TreePath next = next_path( Gtk::TreePath( ( list_info.back() ).path ), true );
@@ -1232,8 +1208,8 @@ void EditTreeView::delete_selected_rows( const bool force )
         m_undo_buffer->set_list_info( CORE::DATA_INFO_LIST(), list_info );
 
         CORE::DATA_INFO_LIST list_info_selected;
-        const bool dir = false;
-        get_info_in_selection( list_info_selected, dir );
+        constexpr bool not_scan_in_dir = false;
+        get_info_in_selection( list_info_selected, not_scan_in_dir );
         m_undo_buffer->set_list_info_selected( list_info_selected );  // redo したときに選択する列
 
         m_undo_buffer->commit();
