@@ -17,11 +17,6 @@
 #include "jdlib/miscutil.h"
 #include "config/globalconf.h"
 
-#include "gtk/gtktextview.h"
-
-#if GTKMM_CHECK_VERSION(3,0,0)
-#include <gdk/gdkkeysyms-compat.h>
-#endif
 
 using namespace SKELETON;
 
@@ -295,9 +290,6 @@ void EditTextView::undo()
     std::cout << udata.str_diff << std::endl;
 #endif
 
-    Glib::ustring text;
-    Glib::ustring text_head = get_buffer()->get_text().substr( 0, udata.pos );
-
     m_cancel_change = true; // slot_buffer_changed() の呼出をキャンセル
 
     // 追加と削除を逆転
@@ -352,7 +344,7 @@ bool EditTextView::on_key_press_event( GdkEventKey* event )
 
     bool cancel_event = false;
     m_delete_pushed = false;
-    if( event->keyval == GDK_Delete ) m_delete_pushed = true;
+    if( event->keyval == GDK_KEY_Delete ) m_delete_pushed = true;
 
     const int controlid = m_control.key_press( event );
 
@@ -377,7 +369,6 @@ bool EditTextView::on_key_press_event( GdkEventKey* event )
         case CONTROL::UndoEdit:
         case CONTROL::InputAA:
         {
-#if GTKMM_CHECK_VERSION(3,0,0)
             if( im_context_filter_keypress( event ) ) {
 #ifdef _DEBUG
                 std::cout << "gtk_im_context_filter_keypress\n";
@@ -385,17 +376,6 @@ bool EditTextView::on_key_press_event( GdkEventKey* event )
                 reset_im_context();
                 return true;
             }
-#else
-            GtkTextView *textview = gobj();
-            if( gtk_im_context_filter_keypress( textview->im_context, event ) )
-            {
-#ifdef _DEBUG    
-                std::cout << "gtk_im_context_filter_keypress\n";
-#endif
-                textview->need_im_reset = TRUE;
-                return true;
-            }
-#endif // GTKMM_CHECK_VERSION(3,0,0)
         }
     }
 
@@ -425,7 +405,7 @@ bool EditTextView::on_key_press_event( GdkEventKey* event )
         case CONTROL::UndoEdit: undo(); return true;
 
         case CONTROL::EnterEdit:
-            event->keyval = GDK_Return;
+            event->keyval = GDK_KEY_Return;
             event->state &= ~GDK_CONTROL_MASK;
             event->state &= ~GDK_SHIFT_MASK;
             event->state &= ~GDK_MOD1_MASK;
@@ -581,25 +561,28 @@ void EditTextView::slot_convert_space()
     }
     else
     {
-        size_t rpos = std::string::npos;
-        size_t nlpos = std::string::npos;
+        std::list<std::string> lines = MISC::get_lines( text );
+        for( std::string& line : lines ) {
 
-        // 改行前のスペースを取り除く
-        while( ( nlpos = text.rfind( "\n", rpos ) ) != std::string::npos )
-        {
-            if( nlpos == 0 ) break;
-            rpos = nlpos;
-            while( text[ rpos - 1 ] == ' ' ) rpos--;
-            text.erase( rpos, nlpos - rpos );
-            rpos--;
+            if( ! line.empty() ) {
+
+                // 行末のスペースを取り除く
+                line.erase( line.find_last_not_of( ' ' ) + 1 );
+
+                // 行頭のスペースを&nbsp;に変換する
+                if( ! line.empty() && line.front() == ' ' ) {
+                    line.replace( 0, 1, "&nbsp;" );
+                }
+
+                // 連続スペースを&nbsp;に変換する
+                converted.append( MISC::replace_str( line, "  ", " &nbsp;" ) );
+            }
+
+            converted.push_back( '\n' );
         }
 
-        // 最後のスペースを取り除く
-        rpos = text.length();
-        while( text[ rpos - 1 ] == ' ' ) rpos--;
-        text.erase( rpos, std::string::npos );
-
-        converted = MISC::replace_str( text, " ", "&nbsp;" );
+        // 最後の改行を取り除く
+        converted.pop_back();
     }
 
     buffer->set_text( converted );
