@@ -353,12 +353,10 @@ public:
 
 
 TabNotebook::TabNotebook( DragableNoteBook* parent )
-    : Gtk::Notebook(),
-      m_parent( parent ),
-      m_fixtab( false ),
-      m_str_empty( std::string() )
+    : Gtk::Notebook()
+    , m_parent( parent )
+    , m_layout_tab{ create_pango_layout( "" ) }
 {
-    m_layout_tab = create_pango_layout( "" );
 
     set_border_width( 0 );
     set_size_request( 1, -1 ); // これが無いと最大化を解除したときにウィンドウが勝手にリサイズする
@@ -653,12 +651,7 @@ void TabNotebook::calc_tabsize()
             int tab_w = -1;
             int tab_h = -1;
 
-#if GTKMM_CHECK_VERSION(2,20,0)
-            const bool mapped = tab->get_mapped();
-#else
-            const bool mapped = tab->is_mapped();
-#endif
-            if( mapped && page ) {
+            if( tab->get_mapped() && page ) {
 
                 tab_x = page->allocation.x;
                 tab_y = page->allocation.y;
