@@ -20,7 +20,7 @@ namespace SKELETON
 
       public:
 
-        ToolBarNotebook( DragableNoteBook* parent );
+        explicit ToolBarNotebook( DragableNoteBook* parent );
         ~ToolBarNotebook() noexcept;
 
 #if !GTKMM_CHECK_VERSION(3,0,0)
