@@ -52,20 +52,11 @@ constexpr const char* JDWindow::s_css_stat_label;
 
 // メッセージウィンドウでは m_mginfo が不要なので need_mginfo = false になる
 JDWindow::JDWindow( const bool fold_when_focusout, const bool need_mginfo )
-    : Gtk::Window( Gtk::WINDOW_TOPLEVEL ),
-      m_gtkwidget( nullptr ),
-      m_gtkwindow( nullptr ),
-      m_grand_parent_class( nullptr ),
-      m_win_moved( false ),
-      m_fold_when_focusout( fold_when_focusout ),
-      m_boot( true ),
-      m_enable_fold( m_fold_when_focusout ),
-      m_transient( false ),
-      m_mode( JDWIN_INIT ),
-      m_count_focusout( 0 ),
-      m_dummywin( nullptr ),
-      m_scrwin( nullptr ),
-      m_vbox_view( nullptr )
+    : Gtk::Window( Gtk::WINDOW_TOPLEVEL )
+    , m_fold_when_focusout( fold_when_focusout )
+    , m_boot( true )
+    , m_enable_fold( m_fold_when_focusout )
+    , m_mode( JDWIN_INIT )
 {
     // ステータスバー
     m_label_stat.set_size_request( 0, -1 );
@@ -195,12 +186,10 @@ void JDWindow::clock_in()
     // 折りたたみ処理
     if( m_fold_when_focusout ){
 
-        int waitcount = 0;
-
         // 遅延リサイズ( focus_in()にある説明を参照 )
         if( m_mode == JDWIN_EXPANDING ){
 
-            waitcount = FOCUS_TIME / TIMER_TIMEOUT;
+            constexpr int waitcount = FOCUS_TIME / TIMER_TIMEOUT;
             ++m_counter;
             if( m_counter > waitcount && ! ( m_counter % waitcount ) ){
 
@@ -246,7 +235,7 @@ void JDWindow::clock_in()
             && ! SESSION::is_iconified_win_main() // メインウィンドウが最小化しているときに transient を外すとウィンドウが表示されなくなる
             && ! SESSION::is_focus_win_main() && ! is_focus_win() ){
 
-            waitcount = FOCUSOUT_TIMEOUT / TIMER_TIMEOUT;
+            constexpr int waitcount = FOCUSOUT_TIMEOUT / TIMER_TIMEOUT;
 
             if( m_count_focusout < waitcount  ) ++m_count_focusout;
             if( m_count_focusout == waitcount ){
@@ -422,12 +411,7 @@ void JDWindow::restore_status()
 // マウスジェスチャ表示
 void JDWindow::set_mginfo( const std::string& mginfo )
 {
-#if GTKMM_CHECK_VERSION(2,20,0)
-    const bool realized = m_mginfo.get_realized();
-#else
-    const bool realized = m_mginfo.is_realized();
-#endif
-    if( realized ) {
+    if( m_mginfo.get_realized() ) {
         m_mginfo.set_text( mginfo );
     }
 }
