@@ -33,8 +33,8 @@ JDWinMain::JDWinMain( const bool init, const bool skip_setupdiag,
 {
 #ifdef _DEBUG
     std::cout << "JDWinMain::JDWinMain init = " << init << std::endl
-              << "x y w h = " << get_x_win() << " " << get_y_win()
-              << " " << get_width_win() << " " << get_height_win() << std::endl;
+              << "x y w h = " << JDWinMain::get_x_win() << " " << JDWinMain::get_y_win()
+              << " " << JDWinMain::get_width_win() << " " << JDWinMain::get_height_win() << std::endl;
 #endif
 
     setlocale( LC_ALL, "ja_JP.UTF-8" );
@@ -61,23 +61,23 @@ JDWinMain::JDWinMain( const bool init, const bool skip_setupdiag,
     bool cancel_maximize = false;
     if( init_w >= 0 ){
         cancel_maximize = true;
-        set_width_win( init_w );
+        JDWinMain::set_width_win( init_w );
     }
     if( init_h >= 0 ){
         cancel_maximize = true;
-        set_height_win( init_h );
+        JDWinMain::set_height_win( init_h );
     }
     if( init_x >= 0 ){
         cancel_maximize = true;
-        set_x_win( init_x );
+        JDWinMain::set_x_win( init_x );
     }
     if( init_y >= 0 ){
         cancel_maximize = true;
-        set_y_win( init_y );
+        JDWinMain::set_y_win( init_y );
     }
     if( cancel_maximize ){
-        set_maximized_win( false );
-        set_full_win( false );
+        JDWinMain::set_maximized_win( false );
+        JDWinMain::set_full_win( false );
     }
 
     // サイズ変更
@@ -97,7 +97,7 @@ JDWinMain::JDWinMain( const bool init, const bool skip_setupdiag,
 
     // migemo 初期化
 #ifdef HAVE_MIGEMO_H
-    jd_migemo_init( CONFIG::get_migemodict_path().c_str() );
+    jdmigemo::init( CONFIG::get_migemodict_path() );
 #endif
 
     // 後はcoreを作って任せる
@@ -109,8 +109,9 @@ JDWinMain::JDWinMain( const bool init, const bool skip_setupdiag,
 JDWinMain::~JDWinMain()
 {
 #ifdef _DEBUG
-    std::cout << "JDWinMain::~JDWinMain window size : x = " << get_x_win() << " y = " << get_y_win()
-              << " w = " << get_width_win() << " h = " << get_height_win() << " max = " << is_maximized_win() << std::endl;
+    std::cout << "JDWinMain::~JDWinMain window size : x = " << JDWinMain::get_x_win()
+              << " y = " << JDWinMain::get_y_win() << " w = " << JDWinMain::get_width_win()
+              << " h = " << JDWinMain::get_height_win() << " max = " << JDWinMain::is_maximized_win() << std::endl;
 #endif
 
     if( m_core ){
@@ -123,7 +124,7 @@ JDWinMain::~JDWinMain()
 
     // migemo のクローズ
 #ifdef HAVE_MIGEMO_H
-    jd_migemo_close();
+    jdmigemo::close();
 #endif
 
     // アイコンマネージャ削除
@@ -271,13 +272,13 @@ bool JDWinMain::on_delete_event( GdkEventAny* event )
 // 最大、最小化
 bool JDWinMain::on_window_state_event( GdkEventWindowState* event )
 {
-#ifdef _DEBUG
-    std::cout << "JDWinMain::on_window_state_event\n";
-    if( m_cancel_state_event ) std::cout << "cancel\n";
-#endif     
-
     // キャンセル ( JDWinMain::on_delete_even() の説明を参照せよ )
-    if( m_cancel_state_event ) return Gtk::Window::on_window_state_event( event );
+    if( m_cancel_state_event ) {
+#ifdef _DEBUG
+        std::cout << "JDWinMain::on_window_state_event cancel" << std::endl;
+#endif
+        return Gtk::Window::on_window_state_event( event );
+    }
 
     return SKELETON::JDWindow::on_window_state_event( event );
 }
@@ -285,13 +286,13 @@ bool JDWinMain::on_window_state_event( GdkEventWindowState* event )
 
 bool JDWinMain::on_configure_event( GdkEventConfigure* event )
 {
-#ifdef _DEBUG
-    std::cout << "JDWinMain::on_configure_event\n";
-    if( m_cancel_state_event ) std::cout << "cancel\n";
-#endif     
-
     // キャンセル ( JDWinMain::on_delete_event() の説明を参照せよ )
-    if( m_cancel_state_event ) return Gtk::Window::on_configure_event( event );
+    if( m_cancel_state_event ) {
+#ifdef _DEBUG
+        std::cout << "JDWinMain::on_configure_event cancel" << std::endl;
+#endif
+        return Gtk::Window::on_configure_event( event );
+    }
 
     return SKELETON::JDWindow::on_configure_event( event );
 }
